package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0D```````````(`/@`!````0"!```````!``````````+#"````
M`````````$``.``(`$``&P`:``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$```````"1<````````)%P`````````
M`"````````$````&`````&``````````8&````````!@8```````Z%\`````
M``#H=0``````````(````````@````8````H8````````"A@8```````*&!@
M``````#P`0```````/`!````````"``````````$````!````!@"````````
M&`)````````8`D```````!@`````````&``````````$`````````%#E=&0$
M````Z%<```````#H5T```````.A70```````U`````````#4``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"``````````O;&EB97AE8R]L9"UE;&8N<V\N,0`````(````
M!`````$```!&<F5E0E-$`(B_#0!A````9P`````````<`````````#L`````
M````+0```&0````D``````````````!/`````````%0```!-`````````#8`
M```]````8@````(````O````5P```%\````X````````````````````'@``
M`%`````F````5@`````````L````8````$X````+`````````&$```!C````
M*0```&8`````````/@````````!3`````````%4```!>```````````````&
M````'0```!(````E````,0````H````Z````0````$0```!<`````````$4`
M```_`````````%(`````````````````````````6````"H````7````2P``
M`"X```!"````````````````````-````!L````%````90```%T```!#````
M`````"`````)````````````````````00````````!9````#P```"$```!&
M````1P```````````````````````````````0``````````````````````
M````````````````````````````````````````#0``````````````````
M````````````````````````````````````````````````````````````
M&@`````````````````````````9````"````!$````````````````````4
M````#`````X`````````%0```"<``````````````````````````P```!@`
M`````````````````````````````````````````````"(````3````````
M````````````,@```````````````````"L`````````'P```!8````H````
M2@`````````U`````````$P````C````40```#``````````````````````
M```````````````W````.0````0```!(````20```!````!:````````````
M```S````/````%L````'````````````````````````````````````=@$`
M`!(``````````````"$!````````W`,``!(`#```44````````4`````````
M[0,``!(`#`!0(4```````#0`````````#````!(``````````````!4`````
M````4@0``!(``````````````!X`````````J@,``!(`#`!`($```````)P`
M````````%@```!(``````````````&$%````````G@(``!(`````````````
M````````````(0```!$`&```P&````````$`````````+P(``!(`````````
M`````*P`````````.````"``````````````````````````DP(``!$`%P`@
M9&````````@`````````3````!(`#0!T5$``````````````````^@,``!(`
M#``044```````-P"````````$`0``!(`#`#0.$```````$T`````````'@0`
M`!(`#``P4$```````,D`````````4@```!(``````````````#L$````````
M6P```!$`&``0P&````````$`````````9@```!(``````````````/``````
M````=````!(``````````````$(`````````-`0``!(`#`#00$```````.(`
M````````0`0``!(`#`"@0$```````"(`````````A````!$`&``@P&``````
M``$`````````D@```!(``````````````&$!````````V@(``!(`````````
M`````"\`````````&P,``!(```````````````P`````````6P0``!(`#`#`
M04```````&T`````````40(``!$`&``DP&````````0`````````EP,``!(`
M``````````````\`````````10,``!(`````````````````````````B`,`
M`!(``````````````&P`````````H````!$`&``PP&````````@`````````
M>`(``!$`&`!`P&```````(`0````````=0,``!(`````````````````````
M````J@```!(``````````````"L`````````4P,``!(```````````````(`
M````````M0```!(```````````````H#````````D`,``!(`````````````
M`%4`````````9`,``!(``````````````-D`````````PP```!$`&`#`T&``
M``````@`````````;`,``!(``````````````)``````````.0(``!(`````
M`````````$H`````````R0```!(``````````````!4`````````U`(``!(`
M`````````````&<`````````UP```!$`&`#(T&````````@`````````Q0(`
M`!(``````````````/0`````````Y````!(````4'D```````,X!````````
M-`(``!(``````````````'$`````````]````!$`&`#0T&````````$`````
M````_P```!(```````````````\!````````$`$``!(``````````````*H'
M````````*P,``!8```````````````@`````````=`,``!(`````````````
M````````````'P$``!$`&`#8T&````````@`````````70,``!(`````````
M````````````````MP(``!(`````````````````````````L0(``!(`````
M````````````````````9P0``!(`#`#P4T```````!0`````````O0(``!(`
M`````````````#0`````````+P$``!(``````````````)$"````````/0$`
M`!(``````````````!\:````````X0(``!(`````````````````````````
M/0,``!(``````````````$P`````````"@,``!(```````````````P`````
M````I0,``!``\?_HOV``````````````````2P$``!$`&`#@U6````````@`
M````````4P$``!(``````````````.0`````````BP(``!(`````````````
M`(\0````````/P(``!(``````````````#$`````````S`(``!(`````````
M``````H`````````<0(``!(``````````````$H`````````7P$``!$`&`#@
MT&````````@`````````;P0``!(`#``@.4```````!X`````````7P(``!$`
M&```T6```````$``````````>@,``!(``````````````'P`````````L0,`
M`!``\?_HU6``````````````````Z`(``!(`````````````````````````
M3`,``!(``````````````%0`````````:@$``!(``````````````#8`````
M````]P(``!$`&`!`T6````````@`````````?0$``!(``````````````)``
M````````B@$``!$`&`!0T6````````$`````````EP$``!$`&`!@T6``````
M`!,`````````W`(``!(``````````````"\`````````BP0``!(`#`#014``
M`````%P*````````I@$``!(``````````````(T`````````G@,``!``\?_H
MOV``````````````````$0```!(```````````````T'````````L0$``!(`
M`````````````,4"````````F`0``!(`#`#`/4```````!<!````````J@0`
M`!(`#``@1$```````*P!````````O`$``!(``````````````&<`````````
M[P(``!(``````````````$H`````````(@,``!(``````````````)L`````
M````IP(``!$`&`"`T6````````@`````````@0,``!(``````````````'X`
M````````MP0``!(`#`#@/D```````+X!````````Q`0``!(`#``P0D``````
M`/`!````````:00``!(`"@!0'$``````````````````RP$``!$`&`"(T6``
M``````@`````````U0$``!(``````````````'P`````````[`$``!(`````
M`````````)T(`````````&QI8G!E<FPN<V\`<&5R;%]F<F5E`'!E<FQ?<&%R
M<V4`4$Q?<&5R;%]D97-T<G5C=%]L979E;`!?2G9?4F5G:7-T97)#;&%S<V5S
M`%]F:6YI`'!E<FQ?<G5N`%!,7VEN7V5V86P`4&5R;%]A=E]S:&EF=`!097)L
M7V=V7V9E=&-H<'8`4$Q?97AI=%]F;&%G<P!097)L7W-V7W-E='!V`%!,7V-O
M;7!C=@!P97)L7V%L;&]C`%!E<FQ?9&]U;G=I;F0`4$Q?;W``4&5R;%]S>7-?
M=&5R;0!03%]E=F%L7W)O;W0`8F]O=%]$>6YA3&]A9&5R`%!,7W1A:6YT960`
M4&5R;%]N97=84U]F;&%G<P!P97)L7V-O;G-T<G5C=`!03%]C=7)S=&%C:VEN
M9F\`4&5R;%]A=E]F971C:`!P97)L7V1E<W1R=6-T`&5N=FER;VX`4&5R;%]M
M9U]S970`4$Q?=&]P7V5N=@!097)L7W-A9F5S>7-M86QL;V,`4&5R;%]N97=3
M5G!V`%!,7V1O7W5N9'5M<`!03%]M96UO<GE?=W)A<`!097)L7V-R;V%K`%!E
M<FQ?;F5W6%,`4&5R;%]S>7-?:6YI=#,`4$Q?<&%R<V5R`%!E<FQ?<V%V95]D
M97-T<G5C=&]R7W@`4&5R;%]S=E\R<'9?9FQA9W,`;&EB;2YS;RXU`&QI8F-R
M>7!T+G-O+C4`;&EB=71I;"YS;RXY`&QI8G1H<BYS;RXS`&]P96X`<F5A9`!C
M;&]S90!?7V5R<F]R`&QI8F,N<V\N-P!?7VUB7W-B7VQI;6ET`%]?<W1A8VM?
M8VAK7V=U87)D`&UE;6-P>0!?1&5F875L=%)U;F5,;V-A;&4`<F5A;&QO8P!?
M7W!R;V=N86UE`')E861L:6YK`%]?<W1D97)R<`!R;61I<@!M:V1I<@!S=')N
M8VUP`'-T<FQE;@!O<&5N9&ER`&QS965K`&%T97AI=`!A8V-E<W,`9V5T<&ED
M`&UE;6UO=F4`7T-U<G)E;G12=6YE3&]C86QE`%]?<W1A8VM?8VAK7V9A:6P`
M<W1R=&]K`&-L;W-E9&ER`%]4:')E8612=6YE3&]C86QE`'-T<FYC<'D`=6YL
M:6YK`&UE;7-E=`!?:6YI=%]T;',`9V5T=6ED`&9P<FEN=&8`<W!R:6YT9@!L
M<W1A=`!S=')S='(`<W1R8VUP`')E861D:7(`<W1R9'5P`&5X96-V<`!?961A
M=&$`7U]B<W-?<W1A<G0`7V5N9``O=7-R+VQO8V%L+VQI8B]P97)L-2\U+C$T
M+C(O;6%C:"]#3U)%`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%A3
M7TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT
M7V5X96-?<')O8P!P87)?9&ER;F%M90!G971?=7-E<FYA;65?9G)O;5]G971P
M=W5I9`!P87)?8VQE86YU<`!X<U]I;FET`%A37TEN=&5R;F%L<U]005)?0TQ%
M05)35$%#2P!P87)?;6MT;7!D:7(`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I
M;F1P<F]G`'!A<E]I;FET7V5N=@!M86EN`$9"4T1?,2XP`$9"4T1?,2XS````
M``(``0`!`````@`!`````@````,````!``$``0`!``$````````````!``$`
M``````(``@`!``(``@`"``(````"``(````"`````@`"`````@`#`````@``
M``(````#``````````0``@````(``@`"``$``@```````@`"``(``0`!````
M`@`#``(``@````$``@`"``$``@`"`````@`````````"``$````!``(````!
M``$````"``(``@`"``$``0`!``````````````````$``0`C`@``$````"``
M``"P*'H'```#`,D$`````````0`"`$<"```0`````````+,H>@<```0`T@0`
M`!````"P*'H'```"`,D$````````&&)@```````2````-```````````````
M`,!@```````%````"0``````````````$,!@```````%````$@``````````
M````(,!@```````%````%P``````````````),!@```````%````'```````
M````````,,!@```````%````(```````````````0,!@```````%````(0``
M````````````P-!@```````%````*```````````````R-!@```````%````
M+0``````````````T-!@```````%````,0``````````````V-!@```````%
M````-@``````````````X-!@```````%````2````````````````-%@````
M```%````2@``````````````0-%@```````%````4```````````````4-%@
M```````%````4@``````````````8-%@```````%````4P``````````````
M@-%@```````%````7P``````````````B-%@```````%````9```````````
M````.&)@```````'`````0``````````````0&)@```````'````!```````
M````````2&)@```````'````!0``````````````4&)@```````'````!P``
M````````````6&)@```````'````"```````````````8&)@```````'````
M"@``````````````:&)@```````'````$0``````````````<&)@```````'
M````$P``````````````>&)@```````'````%```````````````@&)@````
M```'````&```````````````B&)@```````'````&0``````````````D&)@
M```````'````&@``````````````F&)@```````'````'0``````````````
MH&)@```````'````'@``````````````J&)@```````'````'P``````````
M````L&)@```````'````(@``````````````N&)@```````'````(P``````
M````````P&)@```````'````)```````````````R&)@```````'````)0``
M````````````T&)@```````'````)@``````````````V&)@```````'````
M)P``````````````X&)@```````'````*0``````````````Z&)@```````'
M````*@``````````````\&)@```````'````*P``````````````^&)@````
M```'````+````````````````&-@```````'````+@``````````````"&-@
M```````'````+P``````````````$&-@```````'````,```````````````
M&&-@```````'````,@``````````````(&-@```````'````,P``````````
M````*&-@```````'````-0``````````````,&-@```````'````-P``````
M````````.&-@```````'````.```````````````0&-@```````'````.0``
M````````````2&-@```````'````.P``````````````4&-@```````'````
M/```````````````6&-@```````'````/0``````````````8&-@```````'
M````/@``````````````:&-@```````'````/P``````````````<&-@````
M```'````0```````````````>&-@```````'````0P``````````````@&-@
M```````'````1```````````````B&-@```````'````10``````````````
MD&-@```````'````1@``````````````F&-@```````'````1P``````````
M````H&-@```````'````2P``````````````J&-@```````'````30``````
M````````L&-@```````'````3@``````````````N&-@```````'````3P``
M````````````P&-@```````'````40``````````````R&-@```````'````
M5```````````````T&-@```````'````5@``````````````V&-@```````'
M````6```````````````X&-@```````'````60``````````````Z&-@````
M```'````7```````````````\&-@```````'````70``````````````^&-@
M```````'````7@```````````````&1@```````'````8```````````````
M"&1@```````'````90``````````````$&1@```````'````9@``````````
M````2(/L".C'!```Z.(W``!(@\0(PP#_-;Y%(`#_)<!%(``/'T``_R6^12``
M:`````#IX/____\EMD4@`&@!````Z=#_____):Y%(`!H`@```.G`_____R6F
M12``:`,```#IL/____\EGD4@`&@$````Z:#_____)99%(`!H!0```.F0____
M_R6.12``:`8```#I@/____\EAD4@`&@'````Z7#_____)7Y%(`!H"````.E@
M_____R5V12``:`D```#I4/____\E;D4@`&@*````Z4#_____)69%(`!H"P``
M`.DP_____R5>12``:`P```#I(/____\E5D4@`&@-````Z1#_____)4Y%(`!H
M#@```.D`_____R5&12``:`\```#I\/[___\E/D4@`&@0````Z>#^____)39%
M(`!H$0```.G0_O___R4N12``:!(```#IP/[___\E)D4@`&@3````Z;#^____
M)1Y%(`!H%````.F@_O___R4612``:!4```#ID/[___\E#D4@`&@6````Z8#^
M____)09%(`!H%P```.EP_O___R7^1"``:!@```#I8/[___\E]D0@`&@9````
MZ5#^____)>Y$(`!H&@```.E`_O___R7F1"``:!L```#I,/[___\EWD0@`&@<
M````Z2#^____)=9$(`!H'0```.D0_O___R7.1"``:!X```#I`/[___\EQD0@
M`&@?````Z?#]____);Y$(`!H(````.G@_?___R6V1"``:"$```#IT/W___\E
MKD0@`&@B````Z<#]____):9$(`!H(P```.FP_?___R6>1"``:"0```#IH/W_
M__\EED0@`&@E````Z9#]____)8Y$(`!H)@```.F`_?___R6&1"``:"<```#I
M</W___\E?D0@`&@H````Z6#]____)79$(`!H*0```.E0_?___R5N1"``:"H`
M``#I0/W___\E9D0@`&@K````Z3#]____)5Y$(`!H+````.D@_?___R561"``
M:"T```#I$/W___\E3D0@`&@N````Z0#]____)49$(`!H+P```.GP_/___R4^
M1"``:#````#IX/S___\E-D0@`&@Q````Z=#\____)2Y$(`!H,@```.G`_/__
M_R4F1"``:#,```#IL/S___\E'D0@`&@T````Z:#\____)19$(`!H-0```.F0
M_/___R4.1"``:#8```#I@/S___\E!D0@`&@W````Z7#\____)?Y#(`!H.```
M`.E@_/___R7V0R``:#D```#I4/S___\E[D,@`&@Z````Z4#\____)>9#(`!H
M.P```.DP_/__````````````````54B)Y4%53(UO"$%44TB#[`B+'TACPX7;
M3(UDQQ!,B25\M2``?CI(BU<(2(72=#%(B16J0R``#[8"A,!T(TB#P@$\+TB+
M!99#(`!(#T3"2(D%BT,@``^V`DB#P@&$P'7AN"A@8`!(A<!T*TB)]^AB_/__
MOW140`#H6/S__^B/^___B=],B>),B>[H8B$``(G'Z+_^___HJOS__^O6D)"0
MD(`]J;`@``!52(GE=!#K))!(@\`(2(D%-4,@`/_22(L%+$,@`$B+$$B%TG7D
MQ@5]L"```<G##Q]$``!F#Q]$``!52(,]]SX@``!(B>5T%K@`````2(7`=`R_
M(&!@`$F)P\E!_^/)PY"0D)"0D)"0D)`/M@](B?B$R70H2(L%-S4``$B-5P$/
MMC!(B?@/'T0``$`X\0^V"D@/1,)(@\(!A,EU[O/#9@\?1```9@\?1```059(
MC7<X055!5%5(B?U32('L"`(``$R-3"2(38V!@````$R)STB+#DB#Q@A(B<I(
MB<A(P>((2,'@&"4```#_@>(``/\`2`G"2(G(2,'H""4`_P``2`G"2(G(2,'H
M&"7_````2`G"2(G(2,'I*$C!Z"!(B1=(P>`(2(G"2,'@$"4```#_@>(``/\`
M2`G"2(G(2,'I$"4`_P``2`G"2`G*2(E7"$B#QQ!,.<</A77___])C4EH28VQ
M:`(```\?1```2(L!2#-!V$@S0:A(,T&82(G"2`'`2,'J'T@)PH/B_TB)41A(
M@\$(2#GQ==1,BW4`2(M\)(A!O=R\&X](`WT@2(M-"$R+51!(BW483(GP3(GR
M38GQ2,'B!4C!Z!M)B<A("=!,B=))P>@"@^#_2"'*2<'I`DB-O`>9>8):2(G(
M2,'A'DCWT$D)R$@A\$&#X/](`W0DD$@)T$R)P@''3(GP3"'R2/?02(GY3"'0
M2,'I&TP#5"282`G"2(GX2,'@!4B-M!:9>8):2(GZ2`G!3(GP2,'@'@'Q20G!
M2(GX2(G.08/A_TCWT$C![AM,(<I,(<!("=!(B<I-C90"F7F"6DB)R$C!X`5(
M"<9(B<A$`=9)B?I(]]!)P>H"2,'G'DP#1"2@20GZ3"'(2(GW08/B_TC![QM,
M`TPDJ$PATD@)T$B)\DV-A`"9>8):2(GP2,'@!4@)QTB)\$0!QTF)R$C!X1Y)
MP>@"2/?020G(3"'02(GY08/@_TC!Z1M,`U0DL$PAPD@)T$B)^DV-C`&9>8):
M2(GX2,'@!4@)P4B)^$0!R4F)\4C!YAY)P>D"2/?020GQ3"'`2(G.08/A_TC!
M[AM,(<I("=!(B<I-C90"F7F"6DB)R$C!X`5,`T0DN$@)QDB)R$0!UDF)^DC!
MYQY)P>H"2/?020GZ3"'(2(GW08/B_TC![QM,`TPDP$PATD@)T$B)\DV-A`"9
M>8):2(GP2,'@!4@)QTB)\$0!QTF)R$C!X1Y)P>@"2/?020G(3"'02(GY08/@
M_TC!Z1M,`U0DR$PAPD@)T$B)^DV-C`&9>8):2(GX2,'@!4@)P4B)^$0!R4F)
M\4C!YAY)P>D"2/?020GQ3"'`2(G.08/A_TPARDC![AM,`T0DT$@)T$B)RDV-
ME`*9>8):2(G(2,'@!4@)QDB)R$0!UDF)^DC!YQY)P>H"2/?020GZ3"'(2(GW
M08/B_TC![QM,`TPDV$PATD@)T$B)\DV-A`"9>8):2(GP2,'@!4@)QTB)\$0!
MQTF)R$C!X1Y)P>@"2/?020G(3"'02(GY08/@_TC!Z1M,(<)("=!(B?I-C8P!
MF7F"6DB)^$C!X`5("<%(B?A$`<E)B?%(P>8>2<'I`DCWT$D)\4B)SD&#X?],
M`U0DX$PAP$PARDC![AM,`T0DZ$@)T$B)RDV-E`*9>8):2(G(2,'@!4@)QDB)
MR$0!UDF)^DC!YQY)P>H"2/?020GZ3"'(2(GW08/B_TC![QM,`TPD\$PATD@)
MT$B)\DV-A`"9>8):2(GP2,'@!4@)QTB)\$0!QTF)R$C!X1Y)P>@"2/?020G(
M3"'02(GY08/@_TC!Z1M,(<)("=!(B?I-C8P!F7F"6DB)^$C!X`5("<%(B?A$
M`<E)B?%(]]!)P>D"2,'F'DP#5"3X20GQ3"'`2(G.08/A_TC![AM,`P0D3"'*
M2`G02(G*38V4`IEY@EI(B<A(P>`%2`G&2(G(1`'628GZ2,'G'DG!Z@)(]]!)
MB?-)"?I,(<A(B?=!@^+_2,'O&TP#3"0(3"'22`G02(GR38V$`)EY@EI(B?!(
MP>`%2`G'2(GP1`''28G(2,'A'DG!Z`)(]]!)"<A,(=!(B?E!@^#_2,'I&TPA
MPD@)T$B)^DV-C`&9>8):2(GX2,'@!4C!YAY)P>L"3`-4)!!("<%)"?-(B?A!
M@^/_1`')2/?03"':2(G.3"'`28GY2,'N&T@)T$C!YQY)P>D"38V4`IEY@EI(
MB<A,`T0D&$C!X`5)"?E(B<I("<9(B<A!@^'_2/?03"'*1`'63"'82(GW28G*
M2`G02,'A'DC![QM-C80`F7F"6DB)\$G!Z@)(P>`%3`-<)"!)"<I("<=(B?!!
M@^+_2(GR2/?01`''3"'(28GP3"'22`G02,'F'DG!Z`)-C9P#F7F"6DD)\$B)
M^DB)^$&#X/],`TPD*$C!X`5(P>H;2`G"3(G`3#'01`':3`-4)#!(,?A(B=%-
MC8P!H>O9;DB)T$C!Z1M(P>`%2`G!1`')28GY2,'G'DG!Z0)(B<Y)"?E(B==(
MP>X;08/A_TC![P),B<A,,<!,`T0D.$@QT$C!XAY-C90"H>O9;D@)UTB)R(/G
M_TC!X`5("<9(B?A$`=9,,<A,`TPD0$@QR$B)\DV-A`"AZ]EN2(GP2,'J&TC!
MX`5("<)$`<))B<A(P>$>2<'H`DD)R$B)T4&#X/](P>D;3(G`2#'X2`-\)$A(
M,?!-C8P!H>O9;DB)T$C!X`5("<%$`<E)B?%(P>8>2<'I`DD)\4B)SD&#X?](
MP>X;3(G(3#'`3`-$)%!(,=!(C;P'H>O9;DB)R$C!X`5("<8!_DB)UTC!XAY(
MP>\"2`G72(GR@^?_2(GX3#'(2,'J&TP#3"182#'(38V$`*'KV6Y(B?!(P>`%
M2`G"1`'"28G(2,'A'DG!Z`))"<A(B=%!@^#_2,'I&TR)P$@Q^$@#?"1@2#'P
M38V,`:'KV6Y(B=!(P>`%2`G!1`')28GQ2,'F'DG!Z0))"?%(B<Y!@^'_2,'N
M&TR)R$PQP$P#1"1H2#'02(V\!Z'KV6Y(B<A(P>`%2`G&`?Y(B==(P>(>2,'O
M`D@)UTB)\H/G_TB)^$PQR$C!ZAM,`TPD<$@QR$V-A`"AZ]EN2(GP2,'@!4@)
MPD0!PDF)R$C!X1Y)P>@"20G(2(G108/@_TC!Z1M,B<!(,?A(`WPD>$@Q\$V-
MC`&AZ]EN2(G02,'@!4@)P40!R4F)\4C!YAY)P>D"20GQ2(G.08/A_TC![AM,
MB<A,,<!,`X0D@````$@QT$B-O`>AZ]EN2(G(2,'@!4@)Q@'^2(G72,'B'DC!
M[P)("==(B?*#Y_](B?A,,<A(P>H;3`.,)(@```!(,<A-C80`H>O9;DB)\$C!
MX`5("<)$`<))B<A(P>$>2<'H`DD)R$B)T4&#X/](P>D;3(G`2#'X2`.\))``
M``!(,?!-C8P!H>O9;DB)T$C!X`5("<%$`<E)B?%(P>8>2<'I`DD)\4B)SD&#
MX?](P>X;3(G(3#'`3`.$))@```!(,=!(C;P'H>O9;DB)R$C!X`5("<8!_DB)
MUTC!XAY(P>\"2`G72(GR@^?_2(GX3#'(2,'J&TP#C"2@````2#'(38V$`*'K
MV6Y(B?!(P>`%2`G"1`'"28G(2,'A'DG!Z`))B=))"<A(B=%)P>H"08/@_TC!
MZ1M,B<!(,?A(`[PDJ````$@Q\$V-C`&AZ]EN2(G02,'@!4@)P40!R4F)\4C!
MYAY)P>D"28G,20GQ2(G.08/A_TC![AM,B<A,,<!,`X0DL````$@QT$C!XAY(
MC;P'H>O9;DD)TDB)R$&#XO](P>`%2`G&3(G0`?Y,,<A)P>P"2#'(2,'A'DB)
M\DV-A`"AZ]EN20G,2(GP08/D_TP#C"2X````2,'@!4C!ZAM(B?-(BXPDR```
M`$@)PDR)X$C!ZP),,=!$`<),`Y0DP````$@Q\$C!YAY(B==-C8P!H>O9;D@)
M\TB)T(/C_TC!X`5(P>\;2`G'2(G828G33#'@1`'/2<'K`D@QT$C!XAY)B?A-
MC90"H>O9;DD)TTB)^$&#X_](P>`%2<'H&TD)P$P!Z4R)V$4!T$R)VDP!X4@)
MV$@AVDR)QD@A^$F)^4C![AM("=!(P><>2<'I`D@!P4R)P$D)^4C!X`5!@^'_
M38G"2`G&3(G(3(G*`<Y(BXPDT````$P)V$PAVDPAP$B)]T@)T$C![QM)P>`>
M3`'I2<'J`D&\UL%BRD@!V4T)PD@!P4B)\$&#XO](P>`%3(G22`G'3(G0`<](
MBXPDV````$P)R$@A\$F)^$P!Z4P!V4PARDF)\T@)T$C!YAY)P>@;2`'!2(GX
M2<'K`DC!X`5)"?-)"<!!@^/_00'(2(N,).````!,B=A,"=!,B=I,B<9,(=)(
M(?A(P>X;3`'I2`G03`')28GY2,'G'D@!P4R)P$G!Z0)(P>`%20GY2`G&08/A
M_P'.2(N,).@```!,B<A,"=A,B<I(B?=,(=I,(<!,`>E("=!,`=%-B<)(`<%(
MB?!(P>\;2,'@!4G!X!Y)P>H"2`G'30G"`<]!@^+_2(N,)/````!,B=!,B=))
MB?A,"<A,(<I)P>@;3`'I2"'P2`G03`'928GS2`'!2(GX2,'F'DC!X`5)P>L"
M20G`20GS00'(08/C_TB+C"3X````3(G83(G:3(G&3`G03"'22,'N&TP!Z4@A
M^$@)T$P!R4F)^4@!P4R)P$C!X`5("<8!SDC!YQY)P>D"20GY2(N,)``!``!(
MB?=!@^'_2,'O&TR)R$R)RDP)V$PAVDP!Z4PAP$P!T4V)PD@)T$G!X!Y)P>H"
M2`'!2(GP30G"2,'@!4&#XO]("<=,B=!,B=(!STB+C"0(`0``3`G(3"'*2"'P
M28GX2`G02<'H&TP!Z4P!V4F)\TC!YAY(`<%(B?A)P>L"2,'@!4D)P$$!R$D)
M\TB+C"00`0``08/C_TR)QDR)V$R)VDC![AM,"=!,(=),`>E((?A,`<E)B?E(
M"=!(P><>2<'I`D@!P4R)P$D)^4C!X`5!@^'_2`G&3(G(3(G*`<Y(BXPD&`$`
M`$P)V$PAVDPAP$B)]T@)T$C![QM,`>E,`=%-B<))P>`>2`'!2(GP2<'J`DC!
MX`5-"<)("<=!@^+_`<](BXPD(`$``$R)T$R)TDF)^$P!Z4P!V4P)R$PARD@A
M\$F)\TG!Z!M("=!(P>8>2<'K`D@!P4B)^$D)\TC!X`5!@^/_20G`3(G83(G:
M00'(2(N,)"@!``!,"=!,(=)((?A,B<9("=!(P>X;3`'I3`')28GY2,'G'D@!
MP4R)P$G!Z0)(P>`%20GY2`G&08/A_P'.2(N,)#`!``!,B<A,"=A,B<I(B?=,
M(<!,`>E,`=%,(=I-B<)("=!)P>`>2,'O&T@!P4B)\$G!Z@)(P>`%30G"2`G'
M08/B_P'/2(N,)#@!``!,B=!,"<A,B=))B?A,(<I((?!)P>@;3`'I2`G03`'9
M28GS2,'F'D@!P4B)^$G!ZP)(P>`%20GS20G`08/C_T$!R$B+C"1``0``3(G8
M3`G03(G:3(G&3"'22"'X3`'I2`G03`')28GY2`'!3(G`2,'N&TC!X`5(P><>
M2<'I`D@)QDD)^0'.08/A_TB+C"1(`0``3(G(3(G*2(GW3`G83"':2,'O&TP!
MZ4PAP$@)T$P!T4V)PD@!P4B)\$G!X!Y(P>`%2<'J`D@)QTT)P@'/08/B_TB+
MC"10`0``3(G03(G228GX3`G(3"'*2<'H&TP!Z4@A\$@)T$P!V4F)\T@!P4B)
M^$C!X`5)"<!!`<A(P>8>2<'K`DD)\TB+C"18`0``3(G&08/C_TC![AM,B=A,
MB=I,`>E,"=!,(=),`<E((?A)B?E("=!(P><>2<'I`D@!P4D)^4R)P$&#X?],
M`ZPD8`$``$C!X`5("<9,B<A,B<I,"=A,(=H!SDPAP$B)]T@)T$T!U4C![QM)
M`<5(B?!-B<)(P>`%2<'@'DG!Z@)("<=(BY0D:`$``$0![TT)PDF)\$&#XO](
MB?E)P>@"3(G03`'B2,'I&TPQR$P!VD@Q\$C!YAY(`<)(B?A)"?!(P>`%08/@
M_T@)P4R)P`'12(N4)'`!``!,,=!(,?A(B<Y(P>X;3`'B3`'*28GY2,'G'D@!
MPDB)R$G!Z0)(P>`%20GY2`G&08/A_P'62(N4)'@!``!,B<A,,<!(B?=(,<A,
M`>),`=))B<I(`<)(B?!(P>\;2,'@!4C!X1Y)P>H"2`G'20G*`==(BY0D@`$`
M`$&#XO],B=!(B?E,,<A(P>D;3`'B2#'P3`'"28GP2,'F'D@!PDB)^$G!Z`)(
MP>`%20GP2`G!08/@_P'12(N4)(@!``!,B<!,,=!(B<Y(,?A(P>X;3`'B3`'*
M28GY2,'G'D@!PDB)R$G!Z0)(P>`%20GY2`G&`=9(BY0DD`$``$&#X?],B<A(
MB?=,,<!(P>\;3`'B2#'(3`'228G*2,'A'D@!PDB)\$G!Z@)(P>`%20G*2`G'
M08/B_P'72(N4))@!``!,B=!,,<A(B?E(,?!(P>D;3`'B3`'"28GP2,'F'D@!
MPDB)^$G!Z`)(P>`%20GP2`G!08/@_P'12(N4)*`!``!,B<!,,=!(B<Y(,?A(
MP>X;3`'B3`'*28GY2`'"2(G(2,'@!4C!YQY)P>D"2`G&20GY`=9(BY0DJ`$`
M`$&#X?],B<A(B?=,,<!(P>\;3`'B2#'(3`'228G*2,'A'D@!PDB)\$G!Z@)(
MP>`%20G*2`G'08/B_P'72(N4)+`!``!,B=!,,<A(B?E(,?!(P>D;3`'B3`'"
M28GP2,'F'D@!PDB)^$G!Z`)(P>`%20GP2`G!08/@_P'12(N4)+@!``!,B<!(
MB<Y,`>),,=!(P>X;2#'X3`'*28GY2`'"2(G(2,'G'DC!X`5)P>D"2`G&20GY
M`=9(BY0DP`$``$&#X?],B<A(B?=,,<!(P>\;3`'B2#'(3`'228G*2,'A'D@!
MPDB)\$G!Z@)(P>`%20G*2`G'08/B_P'72(N4),@!``!,B=!,,<A(B?E(,?!(
MP>D;3`'B3`'"28GP2`'"2(GX2,'@!4@)P4C!YAY)P>@"`=%)"?!(BY0DT`$`
M`$&#X/](B<Y,B<!(P>X;3`'B3#'02#'X3`'*28GY2`'"2(G(2,'G'DC!X`5)
MP>D"2`G&20GY`=9(BY0DV`$``$&#X?],B<A(B?=)B?-,,<!(P>\;3`'B2#'(
M3`'228G*2,'A'D@!PDB)\$G!Z@)(P>`%20G*2`G'08/B_P'72(N4).`!``!,
MB=!(B?E(B?M,`>),`<),,<A(P>D;2#'P2<'K`DC!YAY(`<)(B?A)"?-(P>`%
M08/C_TC!ZP)("<%,B=@!T4B+E"3H`0``3#'02#'X28G(2,'G'DG!Z!M("?M,
M`>*#X_],`<I)B<E(`<)(B<A(P>`%20G`2(G800'02(N4)/`!``!,,=A(,<A,
MB<=,B<9(P>\;3`'B3`'22`'"3(G`2,'@!4@)QP'72,'A'DG!Z0))"<E(BY0D
M^`$``$C![@)!@^'_2(GY3(G(2,'I&TP!XD@QV$P#I"0``@``3#'`3`':2<'@
M'D@!PDP)QDB)^$C!X`6#YO]("<%(B?!)`=Q,,<@!T4@Q^$B)RDD!Q$B)R$C!
MX@5(P>@;2`G01`'@1`'P2(E%`$B)^$C!YQY(P>@"`TT(2`GX`T40`W481`--
M($B)30A(B4402(EU&$R)32!(@<0(`@``6UU!7$%=05[#3(ED).!,B7PD^$F)
M_$B)7"302(EL)-A)B?=,B6PDZ$R)="3P2(/L.$B%_W4E,<!(BUPD"$B+;"00
M3(MD)!A,BVPD($R+="0H3(M\)#!(@\0XPTR+-0>>(`!-A?9TSP^V!X3`=00Q
MP.L7/#U(B?IT]4B#P@$/M@*$P'5%B=!$*>!)BRY(A>UTI4QCZ$R)\V:03(GJ
M3(GF2(GOZ';F__^%P'4*28U$+0"`.#UT&DB+:PA(@\,(2(7M==?I;____V:0
M/#UUK.NU3"GS2(/``4C!^P-!B1_I5O___P\?@`````!54TB)^TB#[!A(C6PD
M%&:0,<!(B>Y(B=_H`____TB%P'0F2&-$)!1(C13%`````$@#%4J=(`!(@\((
M2(L"2(7`2(E"^'7PZ\A(@\086UW#D$B#[!@QP$B-="04Z,#^__](@\08PP\?
M1```9@\?1```2(/L"(,]"8<@`/]T"XL%`8<@`$B#Q`C#,<"_B%1``.B\____
M2(7`=`</M@"$P'43,<")!=R&(`"+!=:&(`!(@\0(PSPP#Y7`#[;`Z^4/'P!(
M@^P(O______H9N3__S'VOT`Y0`!(@\0(Z=;F__]FD$B+!9&7(`!3,?:_)E9`
M`$B+2`A(BP5FER``#[=0(`^V!:N&(`!F@>+_`8/@?\'B!PG"9HE1`DB+!5N7
M(`!(BU@(Z/[E__](B4,H2(L%1Y<@`$B+4`A(BP4LER``2(E",$B+!3&7(``Q
MTDB+2`A(BP74ER``2(7`=`=(BY"H````2(E1.$B+!0V7(`!(BT`(2,=`0```
M``!(BP7ZEB``2(M`"$C'0"``````2(L%YY8@`$B+4`A(BP7DEB``2(E"2%O#
M#Q^```````\?@`````!,B60DZ$B)7"3828G\2(EL).!,B6PD\$R)="3X2('L
MJ````$B%_W0%@#\`=3-(BYPD@````$B+K"2(````3(ND))````!,BZPDF```
M`$R+M"2@````2('$J````,,/'P#HK^3__TB%P$B)Q73`#Q\`2(GOZ,SB__](
MA<`/A*$```!(C5@(OY-40`"Y`@```/Q(B=[SIG39OY)40`"Y`P```$B)WO.F
M=,A,B>?H1./__TB)WTF)Q>@YX___08U$!0)(8_CHG.'__TB)V4B)QTF)Q4R)
MXKZ55$``,<#HU.+__TB)YDR)[^AIXO__@\`!=!$/MT0D""4`\```/0!```!T
M-DR)[^@KXO__3(GOZ)/D__](B>_H*^+__TB%P`^%7____TB)[^BZY/__3(GG
MZ$+C___I]O[__TR)[^C!_O__D.O'#Q^```````\?@`````!32(G[2(/$@$B)
MYNCDXO__A<!U&`^W1"0()0#P```]`$```'0//0"@``!T"$B#[(`QP%O#2(G?
MO@(```#H(^/__X7`#Y3`2(/L@%L/ML##D$%7,<!!5DF)_D%505152(GU4TB#
M[!B`/CT/E,!(`<5(B>_H+>+__TB-="0408G'3(GW,<#HE_O__TB%P$B)PW0W
M2(G'Z`OB__]$B?I(.=`/@KP````/MD4`2(/%`8@#2(/#`83`=>Y(@\08,<!;
M74%<05U!7D%?PTB+/;&9(`!%,>2X$````$B#/P!T'TB)^DB+0@A!@\0!2(/"
M"$B%P'7O08U$)`)(F$C!X`.+%3Z5(`"%T@^%$`$``$B)Q\<%*94@``$```#H
M^-___TB%P$F)Q0^$&0$``$ECQ$B+-4Z9(`!,B>](C1S%`````$B)VN@_X___
M3(DM-)D@`$B+!2V9(`!(QT0#"`````!$B60D%$$/MA9,B?"$T@^%B````(M<
M)!1%*?=!C7P'`DC!XP-(`QWYF"``Z(C?__](A<!(B0,/A*D```"+5"042(L%
MW9@@`$B+%-!!#[8&A,"(`G0E/#UT(4R)]^L.9@\?1```2(/'`3P]=`X/MD<!
M2(/"`83`B`)UZL8"/0\?@``````/MD4`2(/%`8A"`4B#P@&$P'7MZ;_^__^`
M^CT/A&____](@\`!#[8(A,D/A&#___^`^3UU[.E6____2(G&#Q\`Z'_A__](
MA<!(B051F"``=!!)8\1(C1S%`````.D+____2(/$&+C_____6UU!7$%=05Y!
M7\,/'T0``&8/'T0``$%7059)B?Y!54%40;RE5$``55-(@^Q(3(L]PA@``$F)
MY4C'!"2E5$``2,=$)`B;5$``2,=$)!"H5$``2,=$)!B>5$``2,=$)""C5$``
M2,=$)"BU5$``2,=$)#``````ZQY,B?9,B><QP.B"_?__38ME"$F#Q0A-A>0/
MA(D````QP$R)Y^AG^O__2(7`2(G%=-"`.`!TRTR)]DB)Q^CCX/__2(7`=<A,
MB??HEM___TR)_TB)P^B+W___2(U<`P%(B>_H?M___TB-/`/HY=W__TF)Z$B)
MQTB)PTR)^4R)\K[+54``,<#H&M___TR)YS'`2(G>Z/G\__]-BV4(28/%"$V%
MY`^%=____TB#Q$A;74%<05U!7D%?PV8/'X0``````$B#[#B_P%1``$B+!1"2
M(`!(B40D*#'`2(L%<A<``$B)!"1(BP5O%P``2(E$)`A(BP5K%P``2(E$)!!(
MBP5G%P``2(E$)!@/MP5C%P``9HE$)"`QP.@G^?__,<"_R51``.@;^?__,<"_
MT51``.@/^?__,<"_VE1``.@#^?__,<"_X51``.CW^/__,<"_\51``.CK^/__
M,<"__51``.C?^/__,<"_B%1``.C3^/__,<"_!E5``.C'^/__,<"_$%5``.B[
M^/__,<"_&E5``.BO^/__,<"_)U5``.BC^/__,<"_,%5``.B7^/__,<"_.U5`
M`.C;^/__2(7`=`](B<:_!E5``#'`Z,?[__\QP+],54``Z+OX__](A<!T#TB)
MQK]>54``,<#HI_O__S'`OVE50`#HF_C__TB%P'0V2(G&O_U40``QP.B'^___
M,<"^E55``+_A5$``Z';[__](BT0D*$@S!;J0(`!U44B#Q#C##Q\`,<"_>55`
M`.A4^/__2(7`=!%(B<:_B%1``#'`Z$#[___KMTB-="01OXI50`"Y"@```/SS
MIG6C2(UT)!N_B%1``#'`Z!G[___KD.A&WO__9I!(@^P(Z+O=__^)Q^CDV___
M,=)(A<!T`TB+$$B)T$B#Q`C##Q^```````\?@`````!54TB)^TB#[`A(A?]T
M"`^V+T"$[7402(/$"+^35$``6UWIKMS__^@)W?__2`'82(U0_T@YTP^#G@``
M`$B+/885```/MD#_#[8W0#CP=`GK*@^V"CC!=69(@^H!2#G39I!R[D@YVG4I
M0#HO=*I(@\0(6UWI7=S__P^V`D`XQG3C2(/J`4@YTW+OZ]AF#Q]$``!(@^H!
M2#G3<PD/M@(Z!V:0=.Y(*=HQR4B-0@)(/0`$``!V#DB#Q`A(B<A;7<.)R.NY
M2(/"`4B)WK_`T6``Z#+=__^YP-%@`.O:2(L]Z!0``.N`#Q^```````\?@```
M``!(B5PD\$B);"3X2(/L&$B)^^CZ_O__2(G'Z'+?__](B<4QP.CH]O__A<!T
M"DB%VW0%@#L`=0](BUPD"$B+;"002(/$&,.^EU5``$B)[^@RW?__2#G%==](
MB=](BVPD$$B+7"0(2(/$&.GC]___#Q\`4TB#["")?"0<2(ET)!!(C7PD'$B)
M5"0(2(UT)!!(C50D".A]W?__@#WRCB````^$*0$``(M$)!R`#;%](``#@\`%
M2&/(2(7)#XA*`0``\D@/*L'R#U@%314``&8/+@5-%0``#X=,`0``2(T\S0``
M``#HSMS__TB+="002(G!2(D%(Y,@`$R-2?A(BP9(QT$(G%5``$C'01!`9&``
M2,=!&)]50`!(B0%$BT0D',<%ZI(@``0```!!@_@!?BE,C4GXOP$```"Z"```
M`&8/'T0``$B+!!:#QP%(B40*&$B#P@A!.?A_ZT&-0`2^$%1``$4QP$B82<<$
MP0````"+5"0<2(L]BI(@`(/"`^AFV?__A<")PW1Q2(L]=9(@`.ADV___,<"_
M\51``.A4]?__2(7`=!E(BSU8DB``Z!?9___H<MK__XG82(/$(%O#2(L]1Y(@
M`$B%_W1PZ#7^___KU`\?`.C?V?__2(7`2(G'2(D%'I(@`'1TZ)O:___&!5!\
M(```Z:_^__](BST$DB``Z!/9__^)P^E\____2(G(2(G*2-'H@^(!2`G0\D@/
M*L#R#UC`Z9[^__^^8-%@`+\=5D``,<#HKMO__[_]5$``Z+#T__](A<!(B<=(
MB06[D2``#X5S____Z4G___]`MP'H=-O__T%7059!54%428G\O_U40`!54TB)
M\TB![*@$``!(BP6]C"``2(F$))@$```QP.A>]/__2(LM/Q(``$R)YTF)Q4B)
M[NC=VO__2(7`=#E,B>:_&E5``#'`Z#7W__](BY0DF`0``$@S%7:,(`!,B>`/
MA30!``!(@<2H!```6UU!7$%=05Y!7\-,B>?H5]G__TR+/>P1``!(B=]!B<9,
MB?[H8MC__TB%P$B)PW2B08/&`42)="0,3(VT))`````/'T0``(`[`+B35$``
M2`]$V$V%[70/2(G>3(GOZ`C;__^%P'1^2(G?Z/S8__^)P4B8#[9$`_\Z10!U
M'8U!_TB82(T4&)`/MD+_Q@(`@^D!2(/J`3I%`'3MBT0D#`'(/?\#```/CRC_
M__]-B>!(B>E(B=J^RU5``$R)]S'`Z&C8__](C70D$$R)]^C[U___A<!U$0^W
M1"08)0#P```]`(```'0;,?],B?[HG-?__TB%P$B)PP^%3/___^G3_O__O@$`
M``!,B??H'MG__X7`==1,B?:_&E5``.CY]?__3(GWZ.77__])B<3IM/[__^@8
MV?__#Q]``$%728G_O_U40`!!5D%505154TB![.B!``!(BP40BR``2(F$)-B!
M```QP$C'A"30````HE5``$C'A"38````IU5``$C'A"3@`````````.B-\O__
M2(7`2(G#=`F`.``/A<<"```QP$B-G"30````Z%WZ__](A<!)B<4/A.<!``!!
M#[9%`(3`=%=,B>X/'T0```^^R(7)>#D[#;=Y(`!],61(BQ0E`````$B+!9D;
M(`!(BQ0"2(72#X17`@``2&/!]T3"0``%``!U"@\?@`````#&!E\/MD8!2(/&
M`83`=;%(C:PDH````+]>54``2,>$)*````!>54``2,>$)*@```!754``2,>$
M)+````"W54``2,>$)+@```!T54``2,>$),````"_54``2,>$),@`````````
MZQ%(BWT(2(/%"$B%_P^$3@$``#'`Z)+Q__](A<!(B<-TX(`X`'3;2(G'Z"WT
M__^%P'3/2(G?Z&76__](A<!)B<0/A!T!``!,B>?HL=;__TR)[TB)P^BFUO__
MC80#!`0``$ACZ$B)[^@$U?__2(L5(0\``$B)QTF)QDV)Z4&XEU5``+[)54``
M,<!(B=%(B50D$$R)XN@GUO__OL`!``!,B??HRM;__X/``0^$8`$``$B-="0@
M3(GWZ)36__^%P'45#[=$)"@E`/```#T`0```#X1P`0``28L72(L]G8D@`$R)
M\;[H5D``,<`Q[>C`U?__2(N4)-B!``!(,Q7]B"``2(GH#X6)`@``2('$Z($`
M`%M=05Q!74%>05_#2(G'Z'[5__])B<5(@\,(387M#X49_O__2(L[2(7_#X1(
M`@``,<#H9_#__TB%P'3;@#@`=<M(@\,(387M=-H/'T``Z>K]__]%,>2`/50-
M````2,>$)/````##54``N\-50`!(QX0D^````)-40`!(QX0D``$```````!(
MC:PD\````'4HZ:3^__]-A>0/A9O^__](BUT(2(7;#X2._O__2(/%"(`[``^$
M@?[__TB)W^B.\O__A<!TT4B)W^C&U/__28G$Z\1(BQ56B"``N$#`8`!(A=)(
M#T30Z9']__](B<?HO?3__TB)W^B9U/__2(G%Z>'^___H_-7__X,X$0^$DO[_
M_^CNU?__28L71(L`3(GQ2(L]2H@@`+ZH5D``,<`Q[>APU/__Z:O^__^+7"0L
MZ!+5__\YPP^%?_[__P^W1"0H)?\!```]P`$```^%:O[__TB)[^C]TO__OYY4
M0`!(B<4QP.@J[___2(7`2(G'#X0(`0``Z`W4__])BS](B<;H?OK__TB%P$F)
MQ`^$[````$R)Y^A.U/__@_@#08G`#X]=!0``,<#H!^___X7`=18Q]DR)Y^CM
MTO__A<")1"0<#X6_````OI550`"_B%1``#'`Z+SQ___H6]7__TB+3"0008G`
M0;DF5D``3(GROO!50`!(B>\QP#';Z*G3___K-^CRU/__@S@1=3_H*-7__TB+
M3"00@\,!08G`08G93(GROOY50`!(B>\QP$C'!"0F5D``Z'#3__^^P`$``$B)
M[^@3U/__@\`!=+=,B??H1M7__TB)[K_]5$``,<#H,_'__TB)[^@[\___Z6K]
M__]!O;!50`#I&OS__^A*U/__38LGZ0S___^Z`@```$C'QN[___^)Q^@_T___
MBWPD'$B-M"00`0``N@8```#H6=/__X"\)!`!````=0Z`O"01`0``0P^$TP0`
M`(M\)!PQ]C'23(VD)!"!``#H_-+__[^)J\WOOO[<NIBY\.'2PTC'A"00@0``
M`2-%9TB)O"08@0``28/$.$B)M"0@@0``2,>$)"B!``!V5#(02(F,)#"!``!(
MQX0D.($```````!(QX0D0($```````#'A"2(@0```````(M\)!Q(C;0D$`$`
M`+H`@```Z+#2__^%P$&)Q0^.-0$``$B+C"0X@0``26/52(N$)$"!``!(C9PD
M$`$``(TTT4@YSDB)M"0X@0``2(/0`$C!ZAU(B80D0($``$@!E"1`@0``BY0D
MB($``(72=&3I@````$B+`TB-O"00@0``08/M0$B)A"1(@0``2(M#"$F)1"0(
M2(M#$$F)1"002(M#&$F)1"082(M#($F)1"0@2(M#*$F)1"0H2(M#,$F)1"0P
M2(M#.$B#PT!)B40D..AAU?__08/]/W^;26/52(G>3(GGZ/'2__]$B:PDB($`
M`.D.____N$````!(8_I(C;0D$`$``"G028T\/$$YQ8G#00].W4QC^TR)^NBZ
MTO__B=@#A"2(@0``@_A`B80DB($```^%R_[__TB-C"00`0``02G=2(V\)!"!
M``!)C1P/Z.'4___I>____XM\)!SH%]'__TB+G"0X@0``3(ND)$"!``!(B=A(
MP>@#@^`_2&/0@\`!@_@XQH042($``(`/CJ<"``!(8_BZ0````#'V*<)(C;P\
M2($``$ACTNA:TO__2(V\)!"!``#H>=3__TB-O"00@0``N0<````QP/Q(@\<X
M\TBK3(G@2(V\)!"!``!$B*0D@X$``$C!Z!B(G"2'@0``3(VL))"!``"(A"2`
M@0``3(G@3(V\),"!``!(P>@0B(0D@8$``$R)X$V)[$C!Z`B(A"2"@0``2(G8
M2,'H&(B$)(2!``!(B=A(P>@0B(0DA8$``$B)V#';2,'H"(B$)(:!``#HW=/_
M_TB+E"00@0``2(G0B)0DPX$``$C!Z!B(A"3`@0``2(G02,'H$(B$),&!``!(
MB=!(BY0D&($``$C!Z`B(A"3"@0``2(G0B)0DQX$``$C!Z!B(A"3$@0``2(G0
M2,'H$(B$),6!``!(B=!(BY0D(($``$C!Z`B(A"3&@0``2(G0B)0DRX$``$C!
MZ!B(A"3(@0``2(G02,'H$(B$),F!``!(B=!(BY0D*($``$C!Z`B(A"3*@0``
M2(G0B)0DSX$``$C!Z!B(A"3,@0``2(G02,'H$(B$),V!``!(B=!(BY0D,($`
M`$C!Z`B(A"3.@0``2(G0B)0DTX$``$C!Z!B(A"30@0``2(G02,'H$(B$)-&!
M``!(B=!(P>@(B(0DTH$``$(/MA0[3(GG,<"^ZU5``$B#PP%)@\0"Z-C.__](
M@_L4==[&A"2X@0```$&Y)E9``$V)Z$B+3"003(GROMQ50`!(B>\QP.BJSO__
MZ4?[__](F+_254``28UT!/RX!0```/Q(B<'SI@^%AOK__T&#^`1T&4&-0/Q(
MBU0D$$B800^V1`3_.@(/A6?Z__])BU\(2(7;#X1:^O__2(G?Z)3.__](@_@#
M#X9(^O__2(UT`_R_UU5``+D%````_/.F3`]$X^DM^O__NC@```!(8_@Q]BG"
M2(V\/$B!``!(8]+HL\___^EX_?__@+PD$@$``$$/A1_[__^`O"03`0``0P^%
M$?O__X"\)!0!``!(#X4#^___@+PD%0$``$4/A?7Z__^+?"0<N@(```!(Q\;&
M____Z/'-__^+?"0<2(VT)!`!``"Z*0```.@+SO__3(V$)!`!``!!N2960`#I
MU_[__P\?0`!(B5PDZ$B);"3P3(ED)/A(@>PX"```2(V<)!`$``!(BP6K@"``
M2(F$)!@(```QP.CPSO__N0]60`")PKX45D``,<!(B=_H2LW__X7`>38Q[4B+
ME"08"```2#,5<8`@`$B)Z'5@2(N<)"`(``!(BZPD*`@``$R+I"0P"```2('$
M.`@``,-(B=^Z``0``$B)YNCPR___A<")PWBTC7@!2&/_Z)_+__](A<!TI$AC
MVTB)Q4B)YDB)VDB)Q^A&SO__Q@0K`.N,Z.O-__\/'X``````Z2O___\/'T0`
M`&8/'T0``$%4,<"_X51``,8%L'\@``%54^B)Y___2(7`=`F`.#$/A*,!```Q
MP.BD[?__N@L```"^`0```+\@5D``Z*3+__](A<`/A(`````Q[8,];H0@``%(
MBT`03(M@*'Y<NP@```#K*DB+=Q!(BP5:A"``2(L\&.A]SO__A<!U/8/%`4B#
MPPB-10$Y!36$(`!^*S'2B>Y,B>?H^\S__TB%P'0:2(LX]D<-!'6\,?:Z`@``
M`.AASO__2(G&ZZ^+%0*$(`"-0O\YZ`^$T@```+H$````O@$```"_)59``.@'
MR___2(7`2(G#=")(BT`0OB=60`!(BSCH_LK__TB+0Q!(BSCV1PY`#X74````
MN@0```"^`0```+\Y54``Z,G*__](A<!(B<5T)S'`OQI50`#H<>;__TB%P$B)
MP@^$T0```$B+11!(B=9(BSCHJLK__S'`O_U40`#&!6A^(```2,<%O6T@````
M``#H..;__TB%P$B)!4:#(`!T=K[``0``2(G'Z./+__^%P'01@_@1=`R#^/\/
M'P`/A9\```!;74%<PX/J`6:0#XXC____NP$````/'T0``$R)YX/#`>@9RO__
M.1W_@B``?^WI`?___X!X`0`/'T``#X16_O__Z4K^__\/'T0``.C_R___Z1W_
M__](BSW7@B``Z,KR__](A<!(B06X@B``=6V_0%=``.B(S/__Z-_]__](A<!(
MB<-T.TB+11!(B=Y(BSCHS,G__TB)W^ATS/__Z17___^)P4B+!8J"(`!(BQ5S
M@B``OY!70`!(BS`QP.A`S/__2(M5$$B+!6F"(`!(BSI(BS#HBLG__^G;_O__
M2(M%$$B+'4Z"(`!(BSCV1PT$=#I(BW\02(G>Z)7)__^)PTB+11!(BSCV1PT$
M=#!(BT<02(G"2(L%'((@`(G9OVA70`!(BS`QP.C7R___N@(````Q]NA+S/__
M2(G'Z[FZ`@```#'VZ#K,___KQ@\?0`"Z+%9``+X4'D``OS960`#IP,O__V8/
M'T0``&8/'T0``$B#[`CHU____[DF5D``13'`OA!10`!(B<J_4E9``$B#Q`CI
M_<G__Y"0D)"0D)"0D%5(B>532(/L"$B+!;`+(`!(@_C_=!4QV__02(N#^%]@
M`$B#ZPA(@_C_=>U(@\0(6\G#D)!(@^P(Z&/,__](@\0(PP```````%!!4E]#
M3$5!3@`N+@`E<R\E<P!,24)0051(`$193$1?3$E"4D%265]0051(`%-(3$E"
M7U!!5$@`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%27TE.
M251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]414U0`%!!4E]$14)51P!005)?
M0T%#2$4`4$%27U!23T=.04U%`%!!4E]!4D=#`%!!4E]!4D=67S``4$%27T=,
M3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'
M3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!P87(M
M`"UE`"TM`%5315(`55-%4DY!344`4UE35$5-`%1%35!$25(`5$U0`"]T;7`O
M`"5S)7,E<R5S`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E,#)X`"5S)7-T
M96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P!F:6QE`"]P<F]C+R5I+R5S`$%2
M1U8`&`!P97)L`'!E<FQX<VDN8P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D
M97(`26YT97)N86QS.CI005(Z.D)/3U0`.@``````````7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("```````````,=50```````9U9````````E
M<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*````````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S
M(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O
M<&5R871I;VXI"@```````%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T
M;W)Y```````````E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@``)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T
M;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````````````````````
M``#`0P$;`SO4````&0```%C(___P````:,G__Q@!``"HR?__,`$``)C?__]@
M`0``>.#__X@!``#(X/__J`$``.C@___``0``..'__]@!``!8X?__\`$``"CB
M__\(`@``>./__R@"``#(X___2`(``-CE__^``@``^.;__[@"``"XZ/__T`(`
M`.CH___H`@``V.G__P@#``!(ZO__(`,``#CL__]``P``Z.W__W@#``!(^/__
ML`,``!CY___0`P``*/G__^@#```(_/__"`0``"C\__\@!````````!0`````
M`````7I2``%X$`$##`<(D`$``"0````<````0"!``)P`````00X0A@)##09"
MC0-+@P6,!``````````4````1````%`A0``T```````````````L````7```
M`)`A0`#P%0```$(.$$8.&$(.($$.*(8%C`2-`XX"1`XP1PZX!(,&```D````
MC````(`W0`#9`````$J/`HP%7@Y`C@.-!(8&@P<`````````'````+0```!@
M.$``3P````!!#A!!#AB#`X8"1PXP```4````U````+`X0``5`````$0.(```
M```4````[````-`X0`!-`````$0.$``````4````!`$``"`Y0``>`````$0.
M$``````4````'`$``$`Y0`#"`````$@.$(,"```<````-`$``!`Z0`!"`0``
M`$J#!HP$60ZP`8X"C0.&!1P```!4`0``8#M``$\`````00X0@P)'#I`!````
M````-````'0!``"P.T``!0(```!"#A!$#AB.`X\"10X@0@XH00XPA@:,!8T$
M1`XX1`Y0@P<````````T````K`$``,`]0``7`0```$(.$$(.&(X#CP)%#B!"
M#BB,!8T$1PXP00XX1`Z``8,'A@8``````!0```#D`0``X#Y``+X!````1`Y`
M`````!0```#\`0``H$!``"(`````1`X0`````!P````4`@``T$!``.(`````
M00X000X8@P.&`D<.(```%````#0"``#`04``;0````!.#B"&`H,#'````$P"
M```P0D``\`$```!!#A!$#C"#`@`````````T````;`(``"!$0`"L`0```$(.
M$$(.&$(.($(.*(P%C02.`X\"20XP00XX@P>&!DH.X`D``````#0```"D`@``
MT$5``%P*````0@X0CP)*#AA"#B!"#BA!#C!!#CA'#J"$`H,'A@:,!8T$C@,`
M````'````-P"```P4$``R0````!6#L`0C`*&`X,$```````4````_`(```!1
M0``%```````````````<````%`,``!!10`#<`@```$(.$$\.&$$.((,$A@.,
M`A0````T`P``\%-``!0``````````````!0```!,`P``$%1``"<`````1`X0
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````__________\``````````/__________````````````````````
M``$``````````0`````````!`````````/X!`````````0`````````(`@``
M``````$`````````%@(````````!`````````","`````````0````````!'
M`@````````\`````````M@,````````,`````````%`<0```````#0``````
M``!T5$````````0`````````,`)````````%```````````/0```````!@``
M``````!8!4````````H`````````VP0````````+`````````!@`````````
M%0````````````````````,`````````(&)@```````"`````````*`%````
M````%``````````'`````````!<`````````L!9````````'```````````5
M0```````"`````````"P`0````````D`````````&`````````#^__]O````
M`+`40```````____;P`````"`````````/#__V\`````W!-`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"A@8````````````````````````````'H<0```````BAQ`
M``````":'$```````*H<0```````NAQ```````#*'$```````-H<0```````
MZAQ```````#Z'$````````H=0```````&AU````````J'4```````#H=0```
M````2AU```````!:'4```````&H=0```````>AU```````"*'4```````)H=
M0```````JAU```````"Z'4```````,H=0```````VAU```````#J'4``````
M`/H=0```````"AY````````:'D```````"H>0```````.AY```````!*'D``
M`````%H>0```````:AY```````!Z'D```````(H>0```````FAY```````"J
M'D```````+H>0```````RAY```````#:'D```````.H>0```````^AY`````
M```*'T```````!H?0```````*A]````````Z'T```````$H?0```````6A]`
M``````!J'T```````'H?0```````BA]```````":'T```````*H?0```````
MNA]```````#*'T```````-H?0```````ZA]```````#Z'T````````H@0```
M````&B!````````J($``````````````````)E9``````````````````!A@
M8``````````````````C(2]U<W(O8FEN+W!E<FP*979A;"`G97AE8R`O=7-R
M+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"B`@("!I9B`P.R`C(&YO="!R
M=6YN:6YG('5N9&5R('-O;64@<VAE;&P*"G!A8VMA9V4@7U]P87)?<&P["@HC
M("TM+2!4:&ES('-C<FEP="!M=7-T(&YO="!U<V4@86YY(&UO9'5L97,@870@
M8V]M<&EL92!T:6UE("TM+0HC('5S92!S=')I8W0["@HC;&EN92`Q-3@*"FUY
M("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H
M)$5.5GM005)?0TQ%04Y]*2!["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@
M("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@<F5Q=6ER92!&:6QE.CI3
M<&5C.PH@("`@;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1P87)?=&5M<"D["B`@("!O=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D
M<&%R7W1E;7`B?2D["B`@("!&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@
M*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*("`@(')M
M9&ER("1P87)?=&5M<#L*("`@(",@1&]N)W0@<F5M;W9E('1O<&1I<B!B96-A
M=7-E('1H:7,@8V%U<V5S(&$@<F%C92!W:71H(&]T:&5R(&%P<',*("`@(",@
M=&AA="!A<F4@=')Y:6YG('1O('-T87)T+@H*("`@(&EF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PH@("`@("`@(",@4V]M971H:6YG
M('=E;G0@=W)O;F<@=6YL:6YK:6YG('1H92!T96UP;W)A<GD@9&ER96-T;W)Y
M+B`@5&AI<PH@("`@("`@(",@='EP:6-A;&QY(&AA<'!E;G,@;VX@<&QA=&9O
M<FUS('1H870@9&ES86QL;W<@=6YL:6YK:6YG('-H87)E9`H@("`@("`@(",@
M;&EB<F%R:65S(&%N9"!E>&5C=71A8FQE<R!T:&%T(&%R92!I;B!U<V4N(%5N
M;&EN:R!W:71H(&$@8F%C:V=R;W5N9`H@("`@("`@(",@<VAE;&P@8V]M;6%N
M9"!S;R!T:&4@9FEL97,@87)E(&YO(&QO;F=E<B!I;B!U<V4@8GD@=&AI<R!P
M<F]C97-S+@H@("`@("`@(",@1&]N)W0@9&\@86YY=&AI;F<@;VX@5VEN9&]W
M<R!B96-A=7-E(&]U<B!P87)E;G0@<')O8V5S<R!W:6QL"B`@("`@("`@(R!T
M86ME(&-A<F4@;V8@8VQE86YI;F<@=&AI;F=S('5P+@H*("`@("`@("!M>2`D
M=&UP(#T@;F5W($9I;&4Z.E1E;7`H"B`@("`@("`@("`@(%1%35!,051%(#T^
M("=T;7!86%A86"<L"B`@("`@("`@("`@($1)4B`]/B!&:6QE.CI"87-E;F%M
M93HZ9&ER;F%M92@D=&]P9&ER*2P*("`@("`@("`@("`@4U5&1DE8(#T^("<N
M8VUD)RP*("`@("`@("`@("`@54Y,24Y+(#T^(#`L"B`@("`@("`@*3L*"B`@
M("`@("`@<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@
M+6QT(#$P(%T[(&1O"B`@(')M("UR9B`G)'!A<E]T96UP)PH@("!I9B!;(%PA
M("UD("<D<&%R7W1E;7`G(%T[('1H96X*("`@("`@(&)R96%K"B`@(&9I"B`@
M('-L965P(#$*("`@>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M
M<"T^9FEL96YA;64@+B`B)PHB.PH@("`@("`@("`@("!C:&UO9"`P-S`P+"1T
M;7`M/F9I;&5N86UE.PH@("`@("`@(&UY("1C;60@/2`D=&UP+3YF:6QE;F%M
M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PH@("`@("`@(&-L;W-E("1T;7`[
M"B`@("`@("`@<WES=&5M*"1C;60I.PH@("`@("`@(&]U=',H<7$H4W!A=VYE
M9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"B`@
M("`@("`@("`@("`N("1T;7`M/F9I;&5N86UE*3L*("`@('T*?2!]"@I"14=)
M3B!["B`@("!);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN
M=&5R;F%L<SHZ4$%2.CI"3T]4.PH*("`@(&5V86P@>PH*7W!A<E]I;FET7V5N
M=B@I.PH*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!
M4E]!4D=67S!]("D@>PH@("`@0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?
M)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*("`@("0P(#T@)$5.
M5GM005)?05)'5E\P?3L*?0IE;'-E('L*("`@(&9O<B`H:V5Y<R`E14Y6*2![
M"B`@("`@("`@9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*("`@
M('T*?0H*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*"B,@9FEX("1P
M<F]G;F%M92!I9B!I;G9O:V5D(&9R;VT@4$%42`IM>2`E0V]N9FEG(#T@*`H@
M("`@<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z
M)RDL"B`@("!?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R
M?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`H@("`@7V1E;&EM("`@("`@/3X@
M*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*"E]S971?
M<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PH*(R!-86=I8R!S=')I;F<@
M8VAE8VMI;F<@86YD(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S('M[>PIM
M>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PH@("`@;&]C86P@)%-)1WM?
M7U=!4DY?7WT@/2!S=6(@>WT["@H@("`@(R!#:&5C:R!F:6QE('1Y<&4L(&=E
M="!S=&%R="!O9B!D871A('-E8W1I;VX@>WM["B`@("!O<&5N(%]&2"P@)SPG
M+"`D<')O9VYA;64@;W(@;&%S=#L*("`@(&)I;FUO9&4H7T9(*3L*"B`@("!M
M>2`D8G5F.PH@("`@<V5E:R!?1D@L("TX+"`R.PH@("`@<F5A9"!?1D@L("1B
M=68L(#@["B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*
M"B`@("!S965K(%]&2"P@+3$R+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0[
M"B`@("!S965K(%]&2"P@+3$R("T@=6YP86-K*").(BP@)&)U9BDL(#(["B`@
M("!R96%D(%]&2"P@)&)U9BP@-#L*"B`@("`D9&%T85]P;W,@/2`H=&5L;"!?
M1D@I("T@-#L*("`@(",@?7U]"@H@("`@(R!%>'1R86-T:6YG(&5A8V@@9FEL
M92!I;G1O(&UE;6]R>2![>WL*("`@(&UY("5R97%U:7)E7VQI<W0["B`@("!W
M:&EL92`H)&)U9B!E<2`B1DE,12(I('L*("`@("`@("!R96%D(%]&2"P@)&)U
M9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["@H@("`@("`@(&UY("1F=6QL;F%M92`]("1B=68["B`@("`@("`@;W5T
M<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PH@("`@("`@
M(&UY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@
M*2`_("0Q(#H@=6YD968["B`@("`@("`@;7D@*"1B87-E;F%M92P@)&5X="D@
M/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*("`@("`@("!R
M96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP
M86-K*").(BP@)&)U9BD["@H@("`@("`@(&EF("AD969I;F5D*"1E>'0I(&%N
M9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PH@("`@("`@("`@
M("!M>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C
M*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I
M;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1B=68[
M"B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("`@("`@
M8VAM;V0@,#<U-2P@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE
M;F%M93L*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL
M96YA;65](#T@)&9U;&QN86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H
M("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@*2!["B`@("`@("`@("`@(",@<VAO=6QD(&)E(&UO=F5D('1O
M(%]T96UP9FEL92@I"B`@("`@("`@("`@(&UY("1F:6QE;F%M92`]("(D14Y6
M>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*("`@("`@("`@("`@;W5T<R@B
M4TA,24(Z("1F:6QE;F%M95QN(BD["B`@("`@("`@("`@(&]P96X@;7D@)&]U
M="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM
M;V1E*"1O=70I.PH@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@
M("`@("`@(&-L;W-E("1O=70["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@
M("`@("`@("`@("`D<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0H@("`@("`@
M("`@("`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*
M("`@("`@("`@("`@("`@(&)U9B`]/B`D8G5F+`H@("`@("`@("`@("`@("`@
M8W)C(#T^("1C<F,L"B`@("`@("`@("`@("`@("!N86UE(#T^("1F=6QL;F%M
M92P*("`@("`@("`@("`@?3L*("`@("`@("!]"B`@("`@("`@<F5A9"!?1D@L
M("1B=68L(#0["B`@("!]"B`@("`C('U]?0H*("`@(&QO8V%L($!)3D,@/2`H
M<W5B('L*("`@("`@("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["@H@("`@
M("`@(')E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*"B`@("`@
M("`@;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L
M97T@?'P@9&\@>PH@("`@("`@("`@("!M>2`D:V5Y.PH@("`@("`@("`@("!F
M;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*("`@("`@("`@("`@("`@
M(&YE>'0@=6YL97-S("]<421M;V1U;&5<120O.PH@("`@("`@("`@("`@("`@
M)&ME>2`]("1?.R!L87-T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["B`@
M("`@("`@?2!O<B!R971U<FX["@H@("`@("`@("1)3D-[)&UO9'5L97T@/2`B
M+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["@H@("`@("`@(&EF("@D14Y6
M>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["B`@
M("`@("`@("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D
M:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@
M<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@('-E96LH
M)&9H+"`P+"`P*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]
M"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&UY("@D;W5T+"`D;F%M92D@
M/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PH@("`@("`@
M("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T
M*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F
M?3L*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A
M.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@(')E='5R
M;B`D9F@["B`@("`@("`@?0H*("`@("`@("!D:64@(D)O;W1S=')A<'!I;F<@
M9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*("`@('TL($!)3D,I
M.PH*("`@(",@3F]W(&QO860@86QL(&)U;F1L960@9FEL97,@>WM["@H@("`@
M(R!I;FET:6%L:7IE('-H87)E9"!O8FIE8W0@<')O8V5S<VEN9PH@("`@<F5Q
M=6ER92!84TQO861E<CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E
M<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"B`@("`C
M(&YO=R!L970G<R!T<GD@9V5T=&EN9R!H96QP97(@;6]D=6QE<R!F<F]M('=I
M=&AI;@H@("`@<F5Q=6ER92!)3SHZ1FEL93L*"B`@("`C(&QO860@<F5S="!O
M9B!T:&4@9W)O=7`@:6X*("`@('=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R
M="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["B`@("`@("`@(VQO8V%L("1)
M3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*
M("`@("`@("!U;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@
M/7X@+T)31%!!3B\I('L*("`@("`@("`@("`@(R!R97%U:7)E(&UO9'5L97,L
M(&1O(&]T:&5R(&5X96-U=&%B;&4@9FEL97,*("`@("`@("`@("`@:68@*"1F
M:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["B`@("`@("`@("`@("`@("!R97%U
M:7)E("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E
M('L*("`@("`@("`@("`@("`@(",@4VMI<"!!8W1I=F53=&%T92=S('-I=&5C
M=7-T;VUI>F4N<&P@9FEL93H*("`@("`@("`@("`@("`@(&1O("1F:6QE;F%M
M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1F:6QE;F%M97T["B`@("!]"@H@("`@(R!]?7T*"B`@("!L87-T
M('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*("`@("1S=&%R=%]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L*?0HC('U]?0H*(R!!<F=U;65N="!P<F]C97-S
M:6YG('M[>PIM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G
M9F@L("1C86-H95]N86UE*3L*"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5]
M.R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M
M*0H*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PHC($1O;B=T
M('-W86QL;W<@87)G=6UE;G1S(&9O<B!C;VUP:6QE9"!E>&5C=71A8FQE<R!W
M:71H;W5T("TM<&%R+6]P=&EO;G,*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'
M5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["B`@("!M>2`E
M9&ES=%]C;60@/2!Q=R@*("`@("`@("!P("`@8FQI8E]T;U]P87(*("`@("`@
M("!I("`@:6YS=&%L;%]P87(*("`@("`@("!U("`@=6YI;G-T86QL7W!A<@H@
M("`@("`@(',@("!S:6=N7W!A<@H@("`@("`@('8@("!V97)I9GE?<&%R"B`@
M("`I.PH*("`@(",@:68@=&AE(&%P<"!I<R!I;G9O:V5D(&%S(")A<'!N86UE
M("TM<&%R+6]P=&EO;G,@+2UR975S92!04D]'4D%-($!04D]'7T%21U8B+`H@
M("`@(R!U<V4@=&AE(&%P<"!T;R!R=6X@=&AE(&=I=F5N('!E<FP@8V]D92!I
M;G-T96%D(&]F(&%N>71H:6YG(&9R;VT@=&AE"B`@("`C(&%P<"!I='-E;&8@
M*&)U="!S=&EL;"!S970@=7`@=&AE(&YO<FUA;"!A<'`@96YV:7)O;FUE;G0@
M86YD($!)3D,I"B`@("!I9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E
M=7-E)RD@>PH@("`@("`@('-H:69T($!!4D=6.PH@("`@("`@("1%3E9[4$%2
M7T%04%]2155317T@/2!S:&EF="!`05)'5CL*("`@('T*("`@(&5L<V4@>R`C
M(&YO<FUA;"!P87)L(&)E:&%V:6]U<@H*("`@("`@("!M>2!`861D7W1O7VEN
M8SL*("`@("`@("!W:&EL92`H0$%21U8I('L*("`@("`@("`@("`@)$%21U9;
M,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*"B`@
M("`@("`@("`@(&EF("@D,2!E<2`G22<I('L*("`@("`@("`@("`@("`@('!U
M<V@@0&%D9%]T;U]I;F,L("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<VEF("@D,2!E<2`G32<I('L*("`@("`@("`@("`@("`@(&5V86P@(G5S
M92`D,B(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q
M("=!)RD@>PH@("`@("`@("`@("`@("`@=6YS:&EF="!`<&%R7V%R9W,L("0R
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G3R<I
M('L*("`@("`@("`@("`@("`@("1O=70@/2`D,CL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!E;'-I9B`H)#$@97$@)V(G*2!["B`@("`@("`@("`@("`@
M("`D8G5N9&QE(#T@)W-I=&4G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<VEF("@D,2!E<2`G0B<I('L*("`@("`@("`@("`@("`@("1B=6YD;&4@
M/2`G86QL)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@
M97$@)W$G*2!["B`@("`@("`@("`@("`@("`D<75I970@/2`Q.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G3"<I('L*("`@("`@
M("`@("`@("`@(&]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@
M0V%N;F]T(&]P96X@;&]G.B`D(2(["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS:68@*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@("`@("`@)&-A8VAE
M7VYA;64@/2`D,CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<VAI9G0H
M0$%21U8I.PH*("`@("`@("`@("`@:68@*&UY("1C;60@/2`D9&ES=%]C;61[
M)#%]*2!["B`@("`@("`@("`@("`@("!D96QE=&4@)$5.5GLG4$%27U1%35`G
M?3L*("`@("`@("`@("`@("`@(&EN:71?:6YC*"D["B`@("`@("`@("`@("`@
M("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@("`@("`@("`@("`@("9[(E!!4CHZ
M1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PH@("`@("`@("`@("`@("`@
M)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*("`@("`@("`@
M("`@("`@(&5X:70["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M('5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["B`@("!]"GT*"B,@6%A8("TM
M(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T(0H*(R!]?7T*"B,@3W5T<'5T(&UO
M9&4@*"U/*2!H86YD;&EN9R![>WL*:68@*"1O=70I('L*("`@('L*("`@("`@
M("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@
M)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@24\Z.D9I;&4["B`@("`@("`@
M<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"@H@("`@;7D@)'!A<B`]('-H
M:69T*$!!4D=6*3L*("`@(&UY("1Z:7`["@H*("`@(&EF("AD969I;F5D("1P
M87(I('L*("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B
M0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["B`@("`@("`@8FEN;6]D92@D9F@I
M.PH@("`@("`@(&)L97-S*"1F:"P@)TE/.CI&:6QE)RD["@H@("`@("`@("1Z
M:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@("`@("`H("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"B`@("`@("`@("`@(&]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z
M("0A(CL*("`@('T*"@H@("`@;7D@)65N=B`](&1O('L*("`@("`@("!I9B`H
M)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG
M*2D@>PH@("`@("`@("`@("`D;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*("`@
M("`@("`@("`@)&UE=&$@/7X@<R]>7%,N*B\O;7,["B`@("`@("`@("`@("1M
M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*("`@("`@("!]"B`@("!]
M.PH*("`@(",@3W!E;B!I;G!U="!A;F0@;W5T<'5T(&9I;&5S('M[>PH@("`@
M;&]C86P@)"\@/2!<-#L*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@
M("`@;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*("`@
M("`@("!B:6YM;V1E*%!!4BD["B`@("`@("`@9&EE("(D<&%R(&ES(&YO="!A
M(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PH@("`@
M?0H*("`@($-R96%T95!A=&@H)&]U="D@.PH@("`@"B`@("!M>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W*`H@("`@("`@("1O=70L"B`@("`@("`@24\Z.D9I;&4Z
M.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z
M.D]?5%)53D,H*2P*("`@("`@("`P-S<W+`H@("`@*2!O<B!D:64@)"$["B`@
M("!B:6YM;V1E*"1F:"D["@H@("`@)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I
M(#\@7"1D871A7W!O<R`Z('5N9&5F.PH@("`@<V5E:R!?1D@L(#`L(#`["B`@
M("!M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PH@("`@:68@*"$D14Y6>U!!
M4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2![
M"B`@("`@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("`@
M("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R
M+"`D,"D*("`@('T*("`@(&9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E
M;G8I('L*("`@("`@("!M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PH@
M("`@("`@("1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PH@
M("`@("`@(&UY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@
M(E]?(CL*("`@("`@("!M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B
M/21V86PB.PH@("`@("`@("1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*("`@
M("`@("`@("`@)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M
M(&QE;F=T:"@D<V5T*2DI"B`@("`@("`@?65G.PH@("`@?0H@("`@)&9H+3YP
M<FEN="@D;&]A9&5R*3L*("`@("0O(#T@=6YD968["B`@("`C('U]?0H*("`@
M(",@5W)I=&4@8G5N9&QE9"!M;V1U;&5S('M[>PH@("`@:68@*"1B=6YD;&4I
M('L*("`@("`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("`@("`@4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH@("`@("`@(&EN:71?:6YC*"D[
M"@H@("`@("`@(')E<75I<F5?;6]D=6QE<R@I.PH*("`@("`@("!M>2!`:6YC
M(#T@<V]R="!["B`@("`@("`@("`@(&QE;F=T:"@D8BD@/#T^(&QE;F=T:"@D
M82D*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`A+T)31%!!3B\*("`@
M("`@("!](&=R97`@>PH@("`@("`@("`@("`H)&)U;F1L92!N92`G<VET92<I
M(&]R"B`@("`@("`@("`@("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI
M8F5X<'T@86YD"B`@("`@("`@("`@("`D7R!N92`D0V]N9FEG.CI#;VYF:6=[
M<')I=FQI8F5X<'TI.PH@("`@("`@('T@0$E.0SL*"B`@("`@("`@(R!&:6QE
M(&5X:7-T<R!T97-T(&%D9&5D('1O(&9I>"!25"`C-#$W.3`Z"B`@("`@("`@
M(R!&=6YN>2P@;F]N+65X:7-T:6YG(&5N=')Y(&EN(%\\+BXN+F%U=&\O0V]M
M<')E<W,O4F%W+UIL:6(O875T;W-P;&ET+FEX+@H@("`@("`@(",@5&AI<R!I
M<R!A(&)A;F0M86ED(&9I>"!W:71H(&YO(&1E97!E<B!G<F%S<"!O9B!T:&4@
M:7-S=64N"B`@("`@("`@(R!3;VUE8F]D>2!P;&5A<V4@9V\@=&AR;W5G:"!T
M:&4@<&%I;B!O9B!U;F1E<G-T86YD:6YG('=H870G<R!H87!P96YI;F<L"B`@
M("`@("`@(R!)(&9A:6QE9"X@+2T@4W1E9F9E;@H@("`@("`@(&UY("5F:6QE
M<SL*("`@("`@("`O7E\\*"XK*20O(&%N9"`M92`D,2!A;F0@)&9I;&5S>R0Q
M?2LK(&9O<B!K97ES("4Z.CL*("`@("`@("`D9FEL97-[)%]]*RL@9F]R('9A
M;'5E<R`E24Y#.PH*("`@("`@("!M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O
M;F9I9WML:6)?97AT?3L*("`@("`@("!M>2`E=W)I='1E;CL*"B`@("`@("`@
M9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PH@("`@("`@("`@("!M>2`H
M)&YA;64L("1F:6QE*3L*"B`@("`@("`@("`@(&9O<F5A8V@@;7D@)&1I<B`H
M0&EN8RD@>PH@("`@("`@("`@("`@("`@:68@*"1N86UE(#T@)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD7WTI('L*("`@("`@("`@("`@("`@("`@("`D9FEL
M92`]("1?.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H+UXH7%$D9&ER7$5<+R@N
M*EM>0V-=*2E<6B]I*2!["B`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D
M;F%M92D@/2`H)#$L("0R*3L*("`@("`@("`@("`@("`@("`@("!L87-T.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@*&TA7B]L
M;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["B`@("`@("`@("`@("`@("`@
M("`@:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@
M*"1R968L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@96QS:68@
M*"UF("(D9&ER+R0Q(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I
M;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&YE>'0@=6YL
M97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*
M("`@("`@("`@("`@;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@
M+UPN7%$D;&EB7V5X=%Q%)"\["B`@("`@("`@("`@(&]U=',H(&IO:6X@(B(L
M"B`@("`@("`@("`@("`@("!Q<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D
M9FEL92T^>VYA;65](#H@)&9I;&4L"B`@("`@("`@("`@("`@("!Q<2@B+BXN
M*0H@("`@("`@("`@("`I.PH*("`@("`@("`@("`@;7D@)&-O;G1E;G0["B`@
M("`@("`@("`@(&EF("AR968H)&9I;&4I*2!["B`@("`@("`@("`@("`@("`D
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&]P96X@1DE,12P@)SPG+"`D
M9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*("`@("`@("`@
M("`@("`@(&)I;FUO9&4H1DE,12D["B`@("`@("`@("`@("`@("`D8V]N=&5N
M="`](#Q&24Q%/CL*("`@("`@("`@("`@("`@(&-L;W-E($9)3$4["@H@("`@
M("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY
M*%PD8V]N=&5N="P@)&9I;&4I"B`@("`@("`@("`@("`@("`@("`@:68@(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI
M)"]I.PH*("`@("`@("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E
M;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!O=71S*'%Q*%=R:71T96X@87,@(B1N
M86UE(BDI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*")&24Q%(BD["B`@("`@
M("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y
M*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<W!R:6YT9B@*("`@("`@("`@
M("`@("`@("(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H
M)&-O;G1E;G0I+"`D;F%M90H@("`@("`@("`@("`I*3L*("`@("`@("`@("`@
M)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PH@("`@
M("`@("`@("`D9F@M/G!R:6YT*"1C;VYT96YT*3L*("`@("`@("!]"B`@("!]
M"B`@("`C('U]?0H*("`@(",@3F]W('=R:71E(&]U="!T:&4@4$%2(&%N9"!M
M86=I8R!S=')I;F=S('M[>PH@("`@)'II<"T^=W)I=&54;T9I;&5(86YD;&4H
M)&9H*2!I9B`D>FEP.PH*("`@("1C86-H95]N86UE(#T@<W5B<W1R("1C86-H
M95]N86UE+"`P+"`T,#L*("`@(&EF("@A)&-A8VAE7VYA;64@86YD(&UY("1M
M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PH@("`@("`@(&UY("1C='@@/2!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q
M*2!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("!\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@
M("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X
M(&%N9"`U+C,Y"B`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$
M:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@:68@*"1S:&%?
M=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@
M>PH@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C
M='@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@:68@
M*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PH@("`@("`@("`@
M("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@)&-T>"T^861D
M9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&-A8VAE7VYA;64@/2`D8W1X
M(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PH@("`@?0H@("`@)&-A8VAE
M7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B`@
M("`D8V%C:&5?;F%M92`N/2`B0T%#2$4B.PH@("`@)&9H+3YP<FEN="@D8V%C
M:&5?;F%M92D["B`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BDI*3L*("`@("1F:"T^<')I;G0H(EQN4$%2+G!M
M7&XB*3L*("`@("1F:"T^8VQO<V4["B`@("!C:&UO9"`P-S4U+"`D;W5T.PH@
M("`@(R!]?7T*"B`@("!E>&ET.PI]"B,@?7U]"@HC(%!R97!A<F4@)'!R;V=N
M86UE(&EN=&\@4$%2(&9I;&4@8V%C:&4@>WM["GL*("`@(&QA<W0@=6YL97-S
M(&1E9FEN960@)'-T87)T7W!O<SL*"B`@("!?9FEX7W!R;V=N86UE*"D["@H@
M("`@(R!.;W<@;&]A9"!T:&4@4$%2(&9I;&4@86YD('!U="!I="!I;G1O(%!!
M4CHZ3&EB0V%C:&4@>WM["B`@("!R97%U:7)E(%!!4CL*("`@(%!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"@H@("`@>PH@("`@("`@("-L;V-A
M;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS
M,B<["B`@("`@("`@<F5Q=6ER92!&:6QE.CI&:6YD.PH@("`@("`@(')E<75I
M<F4@07)C:&EV93HZ6FEP.PH@("`@?0H@("`@;7D@)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PH@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*("`@("1F
M:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*
M("`@("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*"B`@
M("!P=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PH@("`@)%!!4CHZ3&EB0V%C
M:&5[)'!R;V=N86UE?2`]("1Z:7`["@H@("`@)'%U:65T(#T@(21%3E9[4$%2
M7T1%0E5'?3L*("`@(&]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](BDI.PH*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!]
M*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0H@("`@("`@(&9O
M<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["B`@("`@("`@
M("`@(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["B`@("`@("`@("`@
M(&UY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PH@("`@("`@
M("`@("!N97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*("`@("`@("`@
M("`@("`@(%X*("`@("`@("`@("`@("`@("\_<VAL:6(O"B`@("`@("`@("`@
M("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*("`@("`@("`@
M("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*("`@("`@
M("`@("`@("`@("A;7B]=*RD*("`@("`@("`@("`@("`@("0*("`@("`@("`@
M("`@?7@["B`@("`@("`@("`@(&UY("1E>'1R86-T7VYA;64@/2`D,3L*("`@
M("`@("`@("`@;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H
M)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PH@("`@("`@("`@("!I
M9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E
M<W-E9%-I>F4H*2D@>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A3:VEP<&EN
M9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B
M)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(&]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B
M)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@("`@("1M96UB97(M/F5X=')A
M8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*("`@("`@("`@("`@("`@(&-H
M;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("`C('U]?0I]"B,@?7U]"@HC
M($EF('1H97)E)W,@;F\@;6%I;BYP;"!T;R!R=6XL('-H;W<@=7-A9V4@>WM[
M"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PH@("`@9&EE
M(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=
M(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M
M+G!L(%T*("`@("`@("0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R
M"BX*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@
M<VAI9G0H0$%21U8I.PI]"B,@?7U]"@IS=6(@0W)E871E4&%T:"!["B`@("!M
M>2`H)&YA;64I(#T@0%\["B`@("`*("`@(')E<75I<F4@1FEL93HZ0F%S96YA
M;64["B`@("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"
M87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["B`@("`*("`@
M(')E<75I<F4@1FEL93HZ4&%T:#L*("`@(`H@("`@1FEL93HZ4&%T:#HZ;6MP
M871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I
M=&@@97)R;W(*?0H*<W5B(')E<75I<F5?;6]D=6QE<R!["B`@("`C;&]C86P@
M)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G
M.PH*("`@(')E<75I<F4@;&EB.PH@("`@<F5Q=6ER92!$>6YA3&]A9&5R.PH@
M("`@<F5Q=6ER92!I;G1E9V5R.PH@("`@<F5Q=6ER92!S=')I8W0["B`@("!R
M97%U:7)E('=A<FYI;F=S.PH@("`@<F5Q=6ER92!V87)S.PH@("`@<F5Q=6ER
M92!#87)P.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@
M17)R;F\["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(')E<75I
M<F4@17AP;W)T97(["B`@("!R97%U:7)E($9C;G1L.PH@("`@<F5Q=6ER92!&
M:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@<F5Q=6ER
M92!84TQO861E<CL*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<F5Q=6ER92!)
M3SHZ2&%N9&QE.PH@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@(')E<75I<F4@
M0V]M<')E<W,Z.EIL:6(["B`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@
M(')E<75I<F4@4$%2.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q
M=6ER92!005(Z.D1I<W0["B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*
M("`@(')E<75I<F4@871T<FEB=71E<SL*("`@(&5V86P@>R!R97%U:7)E($-W
M9"!].PH@("`@979A;"![(')E<75I<F4@5VEN,S(@?3L*("`@(&5V86P@>R!R
M97%U:7)E(%-C86QA<CHZ571I;"!].PH@("`@979A;"![(')E<75I<F4@07)C
M:&EV93HZ56YZ:7`Z.D)U<G-T('T["B`@("!E=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PH@("`@979A;"![(')E<75I<F4@4&5R
M;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["GT*"B,@5&AE($,@=F5R
M<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I;B!M>6QD<B]M:W1M<&1I<BYC
M"B,@5&AI<R!C;V1E(&%L<V\@;&EV97,@:6X@4$%2.CI3971U<%1E;7`@87,@
M<V5T7W!A<E]T96UP7V5N=B$*<W5B(%]S971?<&%R7W1E;7`@>PH@("`@:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+RD@>PH@("`@("`@("1P87)?=&5M<"`]("0Q.PH@("`@("`@(')E
M='5R;CL*("`@('T*"B`@("!F;W)E86-H(&UY("1P871H("@*("`@("`@("`H
M;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!4
M14U0(%1-4"`I*2P*("`@("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N("D*("`@
M("D@>PH@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD
M("1P871H(&%N9"`M=R`D<&%T:#L*("`@("`@("!M>2`D=7-E<FYA;64["B`@
M("`@("`@;7D@)'!W=6ED.PH@("`@("`@(",@9&]E<R!N;W0@=V]R:R!E=F5R
M>7=H97)E.@H@("`@("`@(&5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI
M(&EF(&1E9FEN960@)#X[?3L*"B`@("`@("`@:68@*"!D969I;F5D*"97:6XS
M,CHZ3&]G:6Y.86UE*2`I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)E=I
M;C,R.CI,;V=I;DYA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("AD969I
M;F5D("1P=W5I9"D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D<'=U:60[
M"B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D=7-E<FYA
M;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG
M.PH@("`@("`@('T*("`@("`@("`D=7-E<FYA;64@/7X@<R]<5R]?+V<["@H@
M("`@("`@(&UY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R
M+21U<V5R;F%M92(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@
M("`@("`@:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS
M=&%T*"1P<F]G;F%M92DI6SE=*2!["B`@("`@("`@("`@(&]P96X@*&UY("1F
M:"P@(CPB+B`D<')O9VYA;64I.PH@("`@("`@("`@("!S965K("1F:"P@+3$X
M+"`R.PH@("`@("`@("`@("!S>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*("`@
M("`@("`@("`@:68@*"1B=68@97$@(EPP0T%#2$4B*2!["B`@("`@("`@("`@
M("`@("!S965K("1F:"P@+34X+"`R.PH@("`@("`@("`@("`@("`@<WES<F5A
M9"`D9F@L("1B=68L(#0Q.PH@("`@("`@("`@("`@("`@)&)U9B`]?B!S+UPP
M+R]G.PH@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E
M;&EM?6-A8VAE+2(@+B`D8G5F.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@
M("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[
M($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@("`@("`@("!\?"!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!]
M.PH*("`@("`@("`@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I
M9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("`@("`@("`@(&UY("1S
M:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\
M?"`P.PH@("`@("`@("`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS
M."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`@
M("`@("`@("1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@
M(CPD<')O9VYA;64B*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!B:6YM
M;V1E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I
M;&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE
M+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@('T*
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@
M,3L*("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E
M;7`M)"0B.PH@("`@("`@('T*"B`@("`@("`@)$5.5GM005)?5$5-4'T@/2`D
M<W1M<&1I<CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@
M("!L87-T.PH@("`@?0H*("`@("1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*"G-U8B!?
M=&5M<&9I;&4@>PH@("`@;7D@*"1E>'0L("1C<F,I(#T@0%\["B`@("!M>2`H
M)&9H+"`D9FEL96YA;64I.PH*("`@("1F:6QE;F%M92`]("(D<&%R7W1E;7`O
M)&-R8R1E>'0B.PH*("`@(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@("`@
M("!U;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*("`@("`@("!P
M=7-H($!T;7!F:6QE+"`D9FEL96YA;64["B`@("!]"B`@("!E;'-E('L*("`@
M("`@("!R971U<FX@*'5N9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA
M;64I.PH@("`@?0H*("`@(&]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D
M:64@)"$["B`@("!B:6YM;V1E*"1F:"D["B`@("!R971U<FXH)&9H+"`D9FEL
M96YA;64I.PI]"@HC('-A;64@8V]D92!L:79E<R!I;B!005(Z.E-E='5P4')O
M9VYA;64Z.G-E=%]P<F]G;F%M90IS=6(@7W-E=%]P<F]G;F%M92!["B`@("!I
M9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!2
M3T=.04U%?2`]?B`O*"XK*2\I('L*("`@("`@("`D<')O9VYA;64@/2`D,3L*
M("`@('T*"B`@("`D<')O9VYA;64@?'P]("0P.PH*("`@(&EF("@D14Y6>U!!
M4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@
M/CT@,"D@>PH@("`@("`@("1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L
M(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*("`@
M('T*"B`@("!I9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PH@("`@("`@(&EF("AO
M<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*("`@("`@("`@("`@<F5T
M=7)N(&EF("US("1F:#L*("`@("`@("!]"B`@("`@("`@:68@*"US("(D<')O
M9VYA;64D0V]N9FEG>U]E>&5](BD@>PH@("`@("`@("`@("`D<')O9VYA;64@
M+CT@)$-O;F9I9WM?97AE?3L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@
M('T*("`@('T*"B`@("!F;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF
M:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["B`@("`@("`@;F5X="!I
M9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?
M5$5-4'T["B`@("`@("`@)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D
M+R\["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*("`@("`@("`@("`@
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E
M>&5](CL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*?0H*<W5B(%]F:7A?
M<')O9VYA;64@>PH@("`@)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!2
M3T=.04U%?3L*("`@(&EF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E
M;&EM?2D@/"`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B.PH@("`@?0H*("`@(",@6%A8("T@:&%C:R!T;R!M
M86ME(%!71"!W;W)K"B`@("!M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T
M8W=D*2`_($-W9#HZ9V5T8W=D*"D*("`@("`@("`@("`@("`@(#H@*"AD969I
M;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@
M*3L*("`@(&-H;VUP*"1P=V0I.PH@("`@)'!R;V=N86UE(#U^(',O7B@_/5PN
M7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\[
M"@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"@IS=6(@
M7W!A<E]I;FET7V5N=B!["B`@("!I9B`H("1%3E9[4$%27TE.251)04Q)6D5$
M?2LK(#T](#$@*2!["B`@("`@("`@<F5T=7)N.PH@("`@?2!E;'-E('L*("`@
M("`@("`D14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PH@("`@?0H*("`@(&9O
M<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-
M12!!4D=#($%21U9?,"`I("D@>PH@("`@("`@(&1E;&5T92`D14Y6>R=005)?
M)RXD7WT["B`@("!]"B`@("!F;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$
M14)51R`O*2!["B`@("`@("`@)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%2
M7T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1?
M?3L*("`@('T*"B`@("!M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!
M3E]?("`@("`@("`@("`@("`@(CL*"B`@("!I9B`H)$5.5GM005)?5$5-4'TI
M('L*("`@("`@("!D96QE=&4@)$5.5GM005)?0TQ%04Y].PH@("`@?0H@("`@
M96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PH@("`@
M("`@(&UY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T
M:"@B0TQ%04XB*2D["B`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@)#$@:68@
M)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*("`@('T*?0H*<W5B(&]U
M=',@>PH@("`@<F5T=7)N(&EF("1Q=6EE=#L*("`@(&EF("@D;&]G9F@I('L*
M("`@("`@("!P<FEN="`D;&]G9F@@(D!?7&XB.PH@("`@?0H@("`@96QS92![
M"B`@("`@("`@<')I;G0@(D!?7&XB.PH@("`@?0I]"@IS=6(@:6YI=%]I;F,@
M>PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!P=7-H($!)3D,L(&=R97`@9&5F
M:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`H@("`@("`@(&%R
M8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"B`@
M("`@("`@=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`*("`@("D["GT*"B,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(PHC(%1H92!M86EN('!A8VMA9V4@
M9F]R('-C<FEP="!E>&5C=71I;VX*"G!A8VMA9V4@;6%I;CL*"G)E<75I<F4@
M4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O
M<G0H0'!A<E]A<F=S*3L*"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R
M;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O
M<GE<;BD*("`@('5N;&5S<R`M92`D<')O9VYA;64["@ID;R`D<')O9VYA;64[
M"D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI
M+RD["F1I92`D0"!I9B`D0#L*"GT["@HD.CI?7T524D]2(#T@)$`@:68@)$`[
M"GT*"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*
M"C$["@HC;&EN92`Q,#$Q"@I?7T5.1%]?"@````#_____`"1&<F5E0E-$.B!R
M96QE;F<O.2XQ+VQI8B]C<W4O86UD-C0O8W)T,2YC(#(Q-C,S."`R,#$P+3$R
M+3`Y(#(Q.C,Q.C(Q6B!D:6T@)``D1G)E94)31#H@<F5L96YG+SDN,2]L:6(O
M8W-U+V-O;6UO;B]C<G1B<F%N9"YC(#(Q-S,W-2`R,#$Q+3`Q+3$S(#(P.C0T
M.C,Q6B!D:6T@)`!'0T,Z("A'3E4I(#0N,BXQ(#(P,#<P.#,Q('!A=&-H960@
M6T9R965"4T1=```D1G)E94)31#H@<F5L96YG+SDN,2]L:6(O8W-U+V%M9#8T
M+V-R=&DN4R`R,3<Q,#4@,C`Q,2TP,2TP-R`Q-CHP-SHU,5H@:VEB("0``$=#
M0SH@*$=.52D@-"XR+C$@,C`P-S`X,S$@<&%T8VAE9"!;1G)E94)31%T``$=#
M0SH@*$=.52D@-"XR+C$@,C`P-S`X,S$@<&%T8VAE9"!;1G)E94)31%T``$=#
M0SH@*$=.52D@-"XR+C$@,C`P-S`X,S$@<&%T8VAE9"!;1G)E94)31%T``"1&
M<F5E0E-$.B!R96QE;F<O.2XQ+VQI8B]C<W4O86UD-C0O8W)T;BY3(#(Q-S$P
M-2`R,#$Q+3`Q+3`W(#$V.C`W.C4Q6B!K:6(@)```+G-H<W1R=&%B`"YI;G1E
M<G``+FYO=&4N04))+71A9P`N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV
M97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN
M:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M
M90`N8W1O<G,`+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9V]T+G!L=``N
M9&%T80`N8G-S`"YC;VUM96YT````````````````````````````````````
M```````````````````````````````````````````````````````````+
M`````0````(```````````)``````````@```````!4`````````````````
M```!````````````````````$P````<````"`````````!@"0```````&`(`
M```````8````````````````````!````````````````````"$````%````
M`@`````````P`D```````#`"````````*`,````````$``````````@`````
M````!``````````G````"P````(`````````6`5```````!8!0```````*@)
M````````!0````$````(`````````!@`````````+P````,````"````````
M```/0`````````\```````#;!````````````````````0``````````````
M`````#<```#___]O`@````````#<$T```````-P3````````S@`````````$
M``````````(``````````@````````!$````_O__;P(`````````L!1`````
M``"P%````````%``````````!0````(````(````````````````````4P``
M``0````"```````````50````````!4```````"P`0````````0`````````
M"``````````8`````````%T````$`````@````````"P%D```````+`6````
M````H`4````````$````"P````@`````````&`````````!G`````0````8`
M````````4!Q```````!0'````````!,````````````````````$````````
M````````````8@````$````&`````````&0<0```````9!P```````#0`P``
M````````````````!``````````0`````````&T````!````!@````````!`
M($```````$`@````````-#0``````````````````!``````````````````
M``!S`````0````8`````````=%1```````!T5`````````X`````````````
M```````$````````````````````>0````$````"`````````(A40```````
MB%0```````!@`P``````````````````"````````````````````($````!
M`````@````````#H5T```````.A7````````U`````````````````````0`
M``````````````````"/`````0````(`````````P%A```````#`6```````
M`&0#```````````````````(````````````````````F0````$````#````
M``````!@8````````&`````````0````````````````````"```````````
M`````````*`````!`````P`````````08&```````!!@````````$```````
M``````````````@```````````````````"G`````0````,`````````(&!@
M```````@8`````````@````````````````````(````````````````````
MK`````8````#`````````"A@8```````*&````````#P`0````````4`````
M````"``````````0`````````+4````!`````P`````````88F```````!AB
M````````"`````````````````````@`````````"`````````"Z`````0``
M``,`````````(&)@```````@8@```````/@!```````````````````(````
M``````@`````````PP````$````#`````````"!D8```````(&0```````#(
M6P``````````````````(````````````````````,D````(`````P``````
M````P&```````.B_````````Z!4``````````````````"``````````````
M``````#.`````0````````````````````````#HOP```````.L!````````
M```````````!`````````````````````0````,`````````````````````
K````T\$```````#7`````````````````````0``````````````````````
